@@ -1,30 +1,30 @@
 /* ---------------------------------- about.cpp ---------------------------------------------------------------------------
- Class to display the about dialog
+      Class to display the about dialog
 
-===============================================================================================================================
-===============================================================================================================================
-     This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
-     luckyBackup is distributed under the terms of the GNU General Public License
-     luckyBackup is free software: you can redistribute it and/or modify
-     it under the terms of the GNU General Public License as published by
-     the Free Software Foundation, either version 3 of the License, or
-     (at your option) any later version.
- 
-     luckyBackup is distributed in the hope that it will be useful,
-     but WITHOUT ANY WARRANTY; without even the implied warranty of
-     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-     GNU General Public License for more details.
- 
-     You should have received a copy of the GNU General Public License
-     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
+      ===============================================================================================================================
+      ===============================================================================================================================
+	  This file is part of "luckyBackup" project
+	  Copyright 2008-2010, Loukas Avgeriou
+	  luckyBackup is distributed under the terms of the GNU General Public License
+	  luckyBackup is free software: you can redistribute it and/or modify
+	  it under the terms of the GNU General Public License as published by
+	  the Free Software Foundation, either version 3 of the License, or
+	  (at your option) any later version.
+      
+	  luckyBackup is distributed in the hope that it will be useful,
+	  but WITHOUT ANY WARRANTY; without even the implied warranty of
+	  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	  GNU General Public License for more details.
+      
+	  You should have received a copy of the GNU General Public License
+	  along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
- project version	: Please see "main.cpp" for project version
+      project version	: Please see "main.cpp" for project version
 
- developer 		: luckyb 
- last modified 		: 17 Dec 2009
-===============================================================================================================================
-===============================================================================================================================
+      developer 		: luckyb 
+      last modified 		: 15 Jun 2010
+      ===============================================================================================================================
+      ===============================================================================================================================
 */
 #include "about.h"
 
@@ -65,7 +65,7 @@ void aboutDialog::setAbout()
 		tr("using Qt4")+")" + "<br>" +
 		tr("Backup & Sync Application")+"<br><br>"
 
-		"(C) 2008-2009,	"+
+		"(C) 2008-2010,	"+
 		tr("Loukas Avgeriou") +"<br><br>"
 
 		"web:<br>"
@@ -74,11 +74,9 @@ void aboutDialog::setAbout()
 
 		"<a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\"><img name=\"gpl\""
 		" src=\":/luckyPrefix/gplv3-127x51.png\" width=\"60\" height=\"20\" border=\"0\"></a>&nbsp;&nbsp;"+
-		tr("luckyBackup is distributed under the terms of the")+
-		" <a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\">" +
-		tr("GNU General Public License")+".</a>" +"<br><br>" +
+		tr("luckyBackup is distributed under the terms of the <a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\">GNU General Public License</a>","Please leave the tags <a href=\"http://www.gnu.org/copyleft/gpl.html\" target=\"_blank\"> & </a> intact and surrounding the GNU General Public License !!") +".<br><br>" +
 
-		tr("It is <b>free software</b>: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3 of the License.") +"<br>" +
+		tr("It is <b>free software</b>: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3 of the License.","Please leave tags eg <b>, </b> intact and surrounding the words they are suppossed to !!") +"<br>" +
 		tr("It is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.")+ "<br>" +
 		tr("See the 'License Agreement' tab for more details.")+"</p>";
 
@@ -133,13 +131,16 @@ void aboutDialog::setThanks()
 		"<b>" + tr("Juan Luis Baptiste") + "</b><br>" +
 		tr("Mandriva package maintainer (official contrib repo)") + "<br><br>"
 
+		"<b>" + tr("Thomas Janssen") + "</b><br>" +
+		tr("Fedora package maintainer (official repo)") + "<br><br>"
+
 		"<b>" + tr("Pavel Fric") + "</b><br>" +
 		tr("Czech gui translator") + "<br><br>"
 
 		"<b>" + tr("Stergios Prosiniklis") + "</b><br>" +
 		tr("Greek manual translator") + "<br><br>"
 		
-		"<b>" + tr("Carsten") + "</b><br>" +
+		"<b>" + tr("Karsten Jaschultowski") + "</b><br>" +
 		tr("German gui translator") + "<br><br>"
 
 		"<b>" + tr("Wilfried Schobel") + "</b><br>" +
@@ -154,6 +155,9 @@ void aboutDialog::setThanks()
 		"<b>" + tr("Julien Cynober") + "</b><br>" +
 		tr("French gui translator and valuable packing advisor (and not only)") + "<br><br>"
 
+		"<b>" + tr("Francesco Braile") + "</b><br>" +
+		tr("Italian gui translator") + "<br><br>"
+		
 		"<b>" + tr("Raffaele") + "</b><br>" +
 		tr("Italian gui translator") + "<br><br>"
 		
@@ -184,6 +188,9 @@ void aboutDialog::setThanks()
 		"<b>" + tr("fri13") + "</b><br>" +
 		tr("v.0.3 gui designer") + "<br><br>" +
 
+		"<b>" + tr("Tito Poquito") + "</b><br>" +
+		tr("slackware package maintainer (SlackBuilds Repository)") + "<br><br>" +
+		
 		tr("...to all users of the ")+
 		"<br><a href=\"http://www.linuxformat.gr/\" target=\"_blank\">Hellenic Linuxformat</a>, "
 		"<a href=\"http://www.sidux.com/\" target=\"_blank\">sidux.com</a>, "
@@ -192,11 +199,11 @@ void aboutDialog::setThanks()
 		"<a href=\"http://forum.hellug.gr/\" target=\"_blank\">hellug</a>, "
 		"and <a href=\"http://www.kde-apps.org//\" target=\"_blank\">kde-apps.org</a><br>" +
 		tr("forums for their support.") + "<br><br>" +
-		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams and skevo<br>" +
+		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Carsten, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams, Felix, skevo, Philipp F, Christian Harms, Paul Hewlett and Tristan Gross<br>" +
 		tr("that contributed to this project one way or another") + "<br><br>" +
 
 		tr("Last but no least") +":<br>"+
-		tr("...my other half, <b>Dimitra</b> that bares with me all these times that this project is under development") + " :-)<br></p>";
+		tr("...my other half, <b>Dimitra</b> that bears with me all these times that this project is under development") + " :-)<br></p>";
 	uiA.textBrowser_Thanks-> setText(Text);;
 }
 void aboutDialog::setLicense(QUrl licenseUrl)
