@@ -1,10 +1,10 @@
-/* ---------------------------------- execute.cpp ---------------------------------------------------------------------------
+/* ---------------------------------- executenow.cpp ---------------------------------------------------------------------------
  do everything that deals with commands (rsync & others) execution
 
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 11 Dec 2009
+ last modified 		: 04 Jun 2010
 ===============================================================================================================================
 ===============================================================================================================================
  ********************************** DO NOT FORGET TO CHANGE "commandline.cpp:rsyncIT()" ********************************************************
@@ -37,18 +37,21 @@ QTime StartTime(0,0,0,0);	//find out elapsed time from these;
 void luckyBackupWindow::executeNOW ()
 {
 	NOWexecuting = TRUE;		//this is mainly used if the window close button (or alt+F4) is pressed
+	ABORTpressed = FALSE;		//becomes true if abort button pressed
 	//change gui to execute mode !!
+	guiModeNormal = FALSE;
 	swapGUI("execution");
-	ui.AbortButton -> setText (tr("Abort NOW","push-button text"));
-	ui.AbortButton -> setIcon(QIcon(":/luckyPrefix/abort.png"));
+	ui.AbortButton -> setVisible (TRUE);
+	ui.DoneButton -> setVisible (FALSE);
 	ui.rsyncOutput -> setText("");
 	
 	outputString = "";
 	outputError = "";
 	calculating = FALSE;		//these 3 bools are used to diplay progress of rsync at the info window
-	transfering = FALSE;
+	transferring = FALSE;
 	deleting = FALSE;
 	ExecuteBefore=FALSE;
+	ExecuteBeforeExitedError = FALSE;
 	ExecuteAfter=FALSE;
 	writeToLog=FALSE;
 	errorsFound = 0;		//total error founds during profile execution
@@ -71,7 +74,8 @@ void luckyBackupWindow::executeNOW ()
 	if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
 		LBtray -> showMessage (appName, trayMessage, QSystemTrayIcon::Information,3000);
 	
-	connect ( ui.AbortButton, SIGNAL( clicked() ), this, SLOT( buttonPressed() ) );	//connect abort pushButton SLOT ----------------
+	connect ( ui.AbortButton, SIGNAL( clicked() ), this, SLOT( abortPressed() ) );	//connect abort pushButton SLOT ----------------
+	connect ( ui.DoneButton, SIGNAL( clicked() ), this, SLOT( donePressed() ) );	//connect done pushButton SLOT ----------------
 
 	syncProcess = new QProcess(this);	//create a new qprocess (for rsync) & connect signals
 	connect(syncProcess, SIGNAL(readyReadStandardError()), this, SLOT(appendRsyncOutput()));
@@ -113,20 +117,23 @@ void luckyBackupWindow::swapGUI(QString GUImode)
 		ui.pushButton_down		-> setVisible (FALSE);
 		ui.label_include	-> setVisible (FALSE);
 		ui.menuFile		-> setEnabled (FALSE);
+		ui.menu_Task		-> setEnabled (FALSE);
 		languageMenu		-> setEnabled (FALSE);
 		settingsMenu		-> setEnabled (FALSE);
 		helpMenu		-> setEnabled (FALSE);
 		profileToolbar		-> setEnabled (FALSE);
 		profileComboToolbar	-> setEnabled (FALSE);
 		ui.comboBox_profile	-> setEnabled (FALSE);
-		ui.groupBox_task	-> setEnabled (FALSE);
+		ui.groupBox_task	-> setVisible (FALSE);
 		ui.checkBox_DryRun	-> setEnabled (FALSE);
 		ui.pushButton_exit	-> setVisible (FALSE);
 		ui.label		-> setVisible (FALSE);
 	
 		ui.AbortButton 	-> setVisible (TRUE);
+		ui.DoneButton 	-> setVisible (TRUE);
 		ui.rsyncOutput 	-> setVisible (TRUE);
-		ui.nowDoing	-> setVisible (TRUE);
+		//ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
+		ui.nowDoing	-> setVisible (IsVisibleInfoWindow);
 		ui.OperationProgress -> setVisible (TRUE);
 		ui.pushButton_minimizeToTray	-> setVisible (TRUE);
 		ui.pushButton_nextError	-> setVisible (TRUE);
@@ -137,6 +144,7 @@ void luckyBackupWindow::swapGUI(QString GUImode)
 	else		//change gui to normal mode !!
 	{
 		ui.AbortButton 	-> setVisible (FALSE);
+		ui.DoneButton 	-> setVisible (FALSE);
 		ui.rsyncOutput 	-> setVisible (FALSE);
 		ui.nowDoing	-> setVisible (FALSE);
 		ui.OperationProgress -> setVisible (FALSE);
@@ -146,63 +154,74 @@ void luckyBackupWindow::swapGUI(QString GUImode)
 		
 		ui.pushButton_start	-> setVisible (TRUE);
 		ui.listWidget_operations -> setVisible (TRUE);
-		ui.textBrowser_info	-> setVisible (TRUE);
+		ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
+		ui.textBrowser_info	-> setVisible (IsVisibleInfoWindow);
 		ui.label_TaskList -> setText(tr("Task list","task list label"));
 		ui.frame_operations -> setToolTip(tr("List of all the available tasks","task list tooltip - line1")+"\n"+
 				tr("Use the 'include checkboxes' to include or not a selected task","task list tooltip - line2"));
 		
-		ui.pushButton_up		-> setVisible (TRUE);
-		ui.pushButton_down		-> setVisible (TRUE);
+		ui.pushButton_up	-> setVisible (TRUE);
+		ui.pushButton_down	-> setVisible (TRUE);
 		ui.label_include	-> setVisible (TRUE);
 		ui.menuFile		-> setEnabled (TRUE);
+		ui.menu_Task		-> setEnabled (TRUE);
 		languageMenu		-> setEnabled (TRUE);
 		settingsMenu		-> setEnabled (TRUE);
 		helpMenu		-> setEnabled (TRUE);
 		profileToolbar		-> setEnabled (TRUE);
 		profileComboToolbar	-> setEnabled (TRUE);
 		ui.comboBox_profile	-> setEnabled (TRUE);
-		ui.groupBox_task	-> setEnabled (TRUE);
+		ui.groupBox_task	-> setVisible (TRUE);
 		ui.checkBox_DryRun	-> setEnabled (TRUE);
-		ui.pushButton_exit	-> setVisible (TRUE);
+		ui.pushButton_exit	-> setVisible (FALSE);	// set this to true to make the exit button visible at normal mode
 		ui.label		-> setVisible (TRUE);
 	}
 }
 
-// start-abort-done button pressed=====================================================================================================
-void luckyBackupWindow::buttonPressed()
+// done button pressed=====================================================================================================
+void luckyBackupWindow::donePressed()
 {
-	if (syncProcess->state() == QProcess::NotRunning)	//if syncProcess is not Running
-	{
-		ui.rsyncOutput -> setText("");
-		swapGUI("normal");
-		LBtray -> hide();	// hide the tray icon
-		
-		refreshList(); //refresh the listWidget_operations
-		
-		InfoData = QDateTime::currentDateTime().toString(Qt::DefaultLocaleLongDate) + "<br>" +
-			tr("Execution of profile","full phrase: 'Execution of profile <PROFILENAME> finished'") +
-			" <b>" + profileName + "</b> " + tr("finished","full phrase: 'Execution of profile <PROFILENAME> finished'")+" !!<br>";
-		if (DryRun)
-			InfoData.append("(" + tr("simulation mode") +")");
-		else
-		{
-			if (!savedProfile)
-				InfoData.append(tr("Could not update last execution time of tasks") + "<br>" + profile.errorString());
-			else
-				InfoData.append(tr("Last execution time of tasks updated"));
-		}
-		ui.textBrowser_info -> setText(InfoData);
-	}
+	ui.rsyncOutput -> setText("");
+	guiModeNormal = TRUE;
+	swapGUI("normal");
+	LBtray -> hide();	// hide the tray icon
+	
+	refreshList(); //refresh the listWidget_operations
+	
+	InfoData = QDateTime::currentDateTime().toString(Qt::DefaultLocaleLongDate) + "<br>" +
+		tr("Execution of profile","full phrase: 'Execution of profile <PROFILENAME> finished'") +
+		" <b>" + profileName + "</b> " + tr("finished","full phrase: 'Execution of profile <PROFILENAME> finished'")+" !!<br>";
+	if (DryRun)
+		InfoData.append("(" + tr("simulation mode") +")");
 	else
 	{
-		currentOperation = TotalOperations + 2;		//this means the abort button is pressed to other functions
-		syncProcess -> kill();	//kill rsyncProcess
-		syncProcess -> waitForFinished();
-		currentOperation = TotalOperations + 2;		//this means the abort button is pressed to other functions
-		ExecuteBefore = FALSE;
-		ExecuteAfter = FALSE;
-		setNowDoing ();		//update Nowdoing textBrowser
+		if (!savedProfile)
+			InfoData.append(tr("Could not update last execution time of tasks") + "<br>" + profile.errorString());
+		else
+			InfoData.append(tr("Last execution time of tasks updated"));
 	}
+	ui.textBrowser_info -> setText(InfoData);
+}
+// abort button pressed=====================================================================================================
+void luckyBackupWindow::abortPressed()
+{
+	//if (syncProcess->state() == QProcess::NotRunning)	//if syncProcess is not Running (done pressed)
+
+	// the next condition is used because for some wierd reason the abort button is presses multiple times
+	// if you launch LB, run a profile twice and abort both of them. The second run you abort, will emitt 2 abort clicked() signals !!!
+	if (ABORTpressed)
+		return;
+
+	ui.rsyncOutput->append("<br><br><font color=red>" + tr("Aborting: Please wait for all processes to be killed") + "...</font>");
+	ExecuteBefore = FALSE;
+	ExecuteAfter = FALSE;
+	ABORTpressed = TRUE;
+	
+	syncProcess -> kill();	//kill rsyncProcess
+	syncProcess -> waitForFinished();
+
+	setNowDoing ();		//update Nowdoing textBrowser
+
 }
 
 // createTrayIcon =============================================================================================================================
@@ -215,7 +234,7 @@ void luckyBackupWindow::createTrayIcon()
 	minimizeToTray = new QAction(QIcon(":/luckyPrefix/window_minimize.png"), tr("&Minimize to tray","tray menu action"), this);
 	restoreFromTray = new QAction(QIcon(":/luckyPrefix/window_restore.png"), tr("&Restore","tray menu action"), this);
 	
-	connect( actionAbort, SIGNAL(triggered()), this, SLOT(buttonPressed()));		//tray icon action ABORT
+	connect( actionAbort, SIGNAL(triggered()), this, SLOT(abortPressed()));		//tray icon action ABORT
 	connect( minimizeToTray, SIGNAL(triggered()), this, SLOT(minimizeTray()));			//tray icon action minimize to Tray
 	connect( restoreFromTray, SIGNAL(triggered()), this, SLOT(restoreTray()));		//tray icon action restore from tray
 	
@@ -294,21 +313,128 @@ void luckyBackupWindow::LBtrayActivated(QSystemTrayIcon::ActivationReason reason
  //executes pre-task commands ===============================================================================================
 void luckyBackupWindow::executeBeforeTask()
 {
+	if (ABORTpressed)		//better safe than sorry ;)
+		return;
+	
 	// logfile actions if real run is performed
 	if ( (!DryRun) && (currentBefore == 0) )
 	{
-				//first remove the older logfiles THIS WILL BE TAKEN OUT WHEN SNAPSHOTS ARE INTRODUCED
-				logfilename = logDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
-					(( Operation[currentOperation] -> GetLastExecutionTime() ).toString("yyyyMMddhhmmss")) + ".log";
-				logfile.setFileName(logfilename); // this is the old logfile
-				logfile.remove();
+		int maxSnaps = Operation[currentOperation] -> GetKeepSnapshots();	// this is the number of snapshots to keep
+		if (maxSnaps < 1)
+			maxSnaps = 1;
+		int currentSnaps = Operation[currentOperation] -> GetSnapshotsListSize();	// this is the current number of snapshots
+		if (currentSnaps < 1)
+			currentSnaps = 1;
+		
+		// first remove the older logfiles and snapshots if max keep snapshots is reached
+// *********************************************************** WARNING THIS ONLY WORKS LOCALLY ***********************************************************************
+		bool RemoteDestUsed = (Operation[currentOperation] -> GetRemoteDestination()) && (Operation[currentOperation] -> GetRemote());
+		if ( (currentSnaps >= maxSnaps) &&  (!RemoteDestUsed) )
+		{
+			outputInsert = "\n<font color=magenta>" +
+				tr("Removing old snapshots and logfiles of task","info message displayed during ...data removal\nFull phrase: Removing old snapshots and logfiles of task: <TASKNAME>") +
+				": <b>" + Operation[currentOperation] -> GetName() +
+				"</b></font><br>=====================================<br>";
+			ui.rsyncOutput->append(outputInsert);
+		
+			count = 0;
+			while ( count < (currentSnaps -maxSnaps + 1 ) )
+			{
+				//remove the changes file
+				snapchangesfilename = snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
+							(Operation[currentOperation] -> GetSnapshotsListItem(0)) + ".changes.log";
+				snapfile.setFileName(snapchangesfilename);
+				if (snapfile.exists())
+				{
+					if (snapfile.remove())	// this is the old snapshot changes file
+						ui.rsyncOutput->append("\n" + tr("Removing") +" " + snapchangesfilename);
+					else 
+						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + snapchangesfilename);
+				}
 				
+				//remove the oldest logfile
+				logfilename = logDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
+							(Operation[currentOperation] -> GetSnapshotsListItem(0)) + ".log";
+				logfile.setFileName(logfilename); // this is the old logfile
+				if (logfile.exists())
+				{
+					if (logfile.remove())
+						ui.rsyncOutput->append("\n" + tr("Removing") +" " + logfilename);
+					else
+						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + logfilename);
+				}
+				
+				// **************Remove actual backup data ********
+				
+				// First calculate the folder where snapshots go
+				QStringList tempArguments = Operation[currentOperation] -> GetArgs();
+				QString tempSource = tempArguments[tempArguments.size()-2];
+				QString tempDestination = tempArguments[tempArguments.size()-1];
+				QString sourceLast = tempSource;
+				if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
+				{
+					if (sourceLast.contains(":"))	// this is normal for a remote directory
+						sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
+					if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
+						sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+					
+					tempSource.append("/");
+					tempDestination.append(sourceLast + "/");
+				}
+				tempDestination.append (snapDefaultDir + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
+				
+				// increase the remove limit to include the source.size() if "backup dir by name" is used
+				if (Operation[currentOperation] -> GetTypeDirName())
+					removeCharLimit = 4 + sourceLast.size()+1;
+				else
+					removeCharLimit = 4;
+				
+				QDir snapToRemoveDir(tempDestination);
+				if (snapToRemoveDir.exists())
+				{
+					QProcess *rmProcess;
+					rmProcess  = new QProcess(this);
+					QStringList rmArgs;
+					rmArgs << "-rvf" << tempDestination;
+					rmProcess -> start ("rm",rmArgs);
+					rmProcess -> waitForFinished();
+					
+					
+					if ((rmProcess -> exitCode()) == 0)
+						ui.rsyncOutput->append("\n" + tr("Removing") +" " + tempDestination);
+					else
+						ui.rsyncOutput->append("\n" + tr("failed to remove") +" " + tempDestination);
+				}
+
+				//remove the oldest snapshot (0) from the list
+				Operation[currentOperation] -> RemoveSnapshotsListItem (0);
+				count++;
+			}
+		}
+		if (RemoteDestUsed)
+		{
+			outputInsert = "\n<font color=magenta>" +
+				tr("Using remote destination. Keeping all old snapshots intact","info message displayed during run") +
+				"</font><br>=====================================<br>";
+			ui.rsyncOutput->append(outputInsert);
+		}
+
 		//set the current date and time as the operation's last execution date-time
 		Operation[currentOperation] -> SetLastExecutionTime (QDateTime::currentDateTime());
-		errorCount = 0;		// task starts, so set this to 0
-
+		
+		// add a new snapshot with the last execution date-time
+		Operation[currentOperation] ->
+					AddSnapshotsListItem ((Operation[currentOperation] -> GetLastExecutionTime()).toString("yyyyMMddhhmmss"));
+		currentSnaps = Operation[currentOperation] -> GetSnapshotsListSize();	// update the current number of snapshots
+		
+		// set a new changes file. This has a tag of the previous snapshot will include changes made to this snapshot
+		snapchangesfilename = snapChangesDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
+					(Operation[currentOperation] -> GetSnapshotsListItem(currentSnaps - 1)) + ".changes.log";
+		snapfile.setFileName(snapchangesfilename);
+		
+		// set a new logfile
 		logfilename = logDir + profileName + "-" + Operation[currentOperation] -> GetName() + "-" +
-			(( Operation[currentOperation] -> GetLastExecutionTime() ).toString("yyyyMMddhhmmss")) + ".log";
+			( Operation[currentOperation] -> GetSnapshotsListItem(currentSnaps - 1) ) + ".log";
 		logfile.setFileName(logfilename); // this is the logfile
 		if (logfile.open(QIODevice::WriteOnly | QIODevice::Text))	//create a new log file
 			writeToLog = TRUE;				//& if it's ok set this to TRUE
@@ -316,9 +442,11 @@ void luckyBackupWindow::executeBeforeTask()
 			writeToLog = FALSE;
 	}
 
+	errorCount = 0;		// task starts, so set this to 0 no matter dry or real run
+	
 	// execute commands before task -----------------------------------------------------------------------------------------------------
-	//if there are no (more) pre-task commands to be executed
-	if (Operation[currentOperation] -> GetExecuteBeforeListSize() == currentBefore) 	
+	//if there are no (more) pre-task commands to be executed || the previous pre-task command exited with an error
+	if ( (Operation[currentOperation] -> GetExecuteBeforeListSize() == currentBefore) || (ExecuteBeforeExitedError) )
 	{
 		currentBefore = 0;
 		ExecuteBefore=FALSE;
@@ -328,6 +456,7 @@ void luckyBackupWindow::executeBeforeTask()
 	else
 	{
 		ExecuteBefore=TRUE;
+		ExecuteBeforeExitedError = FALSE;
 		outputInsert = logFileUpdate("pre-starting","",currentBefore);
 
 		ui.rsyncOutput->append(outputInsert);
@@ -340,25 +469,59 @@ void luckyBackupWindow::executeBeforeTask()
  //executes post-task commands ===============================================================================================
 void luckyBackupWindow::executeAfterTask()
 {
+	if (ABORTpressed)		//better safe than sorry :)
+		return;
+	
 	// execute commands after task -----------------------------------------------------------------------------------------------------
-	//if there are no (more) post-task commands to be executed
-	if (Operation[currentOperation] -> GetExecuteAfterListSize() == currentAfter) 	
+	//if there are no (more) post-task commands to be executed or we are here because a pre-task command exited with an error or destination could not be created
+	if ( (Operation[currentOperation] -> GetExecuteAfterListSize() == currentAfter) || (ExecuteBeforeExitedError) || (DestCreateFail) )
 	{
 		if (!DryRun)
+		{
 			logfile.close();	//close the logfile first (will create a new one for the next task)
+			Operation[currentOperation] -> SetLastExecutionErrors (errorCount);	// update the last execution errors
+			
+			// strip unused lines from the snapshot changes file ~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
+			QString filesAdded = "", snapLine = "";
+			if (snapfile.open(QIODevice::ReadOnly | QIODevice::Text))
+			{
+				ui.rsyncOutput->append(".");
+				QTextStream in(&snapfile);
+				while (!in.atEnd())
+				{
+					snapLine = in.readLine();
+					if (snapLine.contains("+++++++", Qt::CaseInsensitive))
+					{
+						snapLine = snapLine.right(snapLine.size()-snapLine.lastIndexOf("[LB]")-removeCharLimit) + "\n";
+						filesAdded.append(snapLine);
+					}
+				}
+				snapfile.close();
+			}
+
+			if (snapfile.open(QIODevice::WriteOnly))
+			{
+				ui.rsyncOutput->append(".");
+				QTextStream out(&snapfile);
+				out << filesAdded;
+				snapfile.close();
+			}
+		}
 
 		currentAfter = 0;
 		ExecuteAfter=FALSE;
 
-		Operation[currentOperation] -> SetLastExecutionErrors (errorCount);
-		errorCount = 0;
+		errorCount = 0;		// reset the current task error count
 
 		currentOperation++;
 		//increase currentOperation until next operation to be executed or end of operations
 		while ( (currentOperation < TotalOperations) && (!Operation[currentOperation] -> GetPerform()) )
 			currentOperation++;
 		if (currentOperation < TotalOperations)
+		{
+			ExecuteBeforeExitedError = FALSE;
 			executeBeforeTask();
+		}
 		else
 			setNowDoing();
 	}
@@ -375,6 +538,15 @@ void luckyBackupWindow::executeAfterTask()
 //executes rsync  ===============================================================================================
 void luckyBackupWindow::executeRsync()
 {
+	if (ABORTpressed)		//better safe than sorry :)
+		return;
+	
+	if (ExecuteBeforeExitedError)	// if a pre-task command exited with an error do not do anything
+	{
+		procFinished();
+		return;
+	}
+	
 	sync = Operation[currentOperation] -> GetTypeSync();		//set sync variable according to checkstate of radiobutton operation type
 	rsyncArguments = AppendArguments(Operation[currentOperation]);	//set rsync arguments
 
@@ -406,8 +578,29 @@ void luckyBackupWindow::executeRsync()
 	if ((sync) && (syncAB))
 		outputInsert = logFileUpdate("rsync-starting-syncBA", "", 0);
 
+	DestCreateFail = FALSE;	 // This will become TRUE if destination does not exist and cannot be created
 	if (!sync)
+	{
 		outputInsert = logFileUpdate("rsync-starting-backup", "", 0);
+		
+		// Create the destination if it does not exist
+		QDir destCreate (dirB);
+		if (!destCreate.exists())
+		{
+			if (destCreate.mkpath(dirB))
+				outputInsert.append(logFileUpdate("rsync-standard", "<br>" + tr("Successfuly created destination directory"), 0));
+			else
+			{
+				outputInsert.append(logFileUpdate("rsync-error", "<br>" +tr("Failed to create destination directory"), 0));
+				ui.rsyncOutput->append(outputInsert);
+				DestCreateFail = TRUE;
+				errorsFound++;
+				errorCount++;
+				procFinished();	// Do not proceed any further
+				return;
+			}
+		}
+	}
 
 	ui.rsyncOutput->append(outputInsert);
 	//set the progressbar to 0
@@ -420,13 +613,17 @@ void luckyBackupWindow::executeRsync()
 //when rsyncProcess emits finished signal execute another RsyncProcess if any left====================================================================
 void luckyBackupWindow::procFinished()
 {
-	if (!(currentOperation < TotalOperations)) //this is to prevent segmentation fault when abort button pressed (currentOperation=totalOperaions+2)
+	if (ABORTpressed) //this is to prevent segmentation fault when abort button pressed
 		return;
-
+				
 	if (ExecuteBefore)		// if the pre-task execution command (process) finished
 	{
 		outputInsert = logFileUpdate("pre-finished", "", currentBefore);
 		ui.rsyncOutput->append(outputInsert);
+		if (syncProcess -> exitCode() != 0)	// if the pre-task command exited with an error
+			ExecuteBeforeExitedError = TRUE;
+		else
+			ExecuteBeforeExitedError = FALSE;
 		currentBefore++; 	//go to the next pre-task execution command 
 
 		executeBeforeTask();	//and executeBeforeTask again
@@ -444,11 +641,16 @@ void luckyBackupWindow::procFinished()
 	}
 
 	//display a couple of lines to indicate end of task
-	if ((!sync) || ((sync) && (syncAB)) )
-		outputInsert = logFileUpdate("rsync-finished", "", 0);
-
+	if (ExecuteBeforeExitedError)
+		outputInsert = logFileUpdate("pre-task-exited-with-error", "", 0);
 	else
-		outputInsert = logFileUpdate("rsync-finished-sync1", "", 0);
+	{
+		if ((!sync) || ((sync) && (syncAB)) )
+			outputInsert = logFileUpdate("rsync-finished", "", 0);
+
+		else
+			outputInsert = logFileUpdate("rsync-finished-sync1", "", 0);
+	}
 	
 	ui.rsyncOutput->append(outputInsert);
 
@@ -461,6 +663,9 @@ void luckyBackupWindow::procFinished()
 //update dialog with new data (text - progressbar) - also update logfile =======================================================================
 void luckyBackupWindow::appendRsyncOutput()
 {
+	if (ABORTpressed)		//better safe than sorry :)
+		return;
+	
 	setNowDoing ();		//update Nowdoing textBrowser
 	
 	//update textBrowser ------------------------------------------------------------------------------------------------------
@@ -507,19 +712,19 @@ void luckyBackupWindow::appendRsyncOutput()
 	if (outputString.contains("building file list"))
 	{
 		calculating = TRUE;
-		transfering = FALSE;
+		transferring = FALSE;
 		deleting = FALSE;
 	}
 	if (outputString.contains("files to consider"))
 	{
 		calculating = FALSE;
-		transfering = TRUE;
+		transferring = TRUE;
 		deleting = FALSE;
 	}
 	if (outputString.contains("deleting"))
 	{
 		calculating = FALSE;
-		transfering = FALSE;
+		transferring = FALSE;
 		deleting = TRUE;
 	}
 }
@@ -532,64 +737,66 @@ void luckyBackupWindow::setNowDoing()
 	int elapsedMsec = StartTime.elapsed();
 	DifTime = DifTime.addMSecs(elapsedMsec);
 	
-	if ( (ExecuteBefore) && (currentOperation < TotalOperations) )
-		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>"+tr("pre-task execution of command")+"	: <b>" +
-				Operation[currentOperation] -> GetExecuteBeforeListItem(currentBefore) + "</b>";
-
-	if ( (ExecuteAfter) && (currentOperation < TotalOperations) )
-		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>"+tr("post-task execution of command")+"	: <b>" +
-				Operation[currentOperation] -> GetExecuteAfterListItem(currentAfter) + "</b>";
-
-	if ( (sync) && (currentOperation < TotalOperations) && (!ExecuteAfter) && (!ExecuteBefore) )	//if a sync operation is executed
+	if ( (currentOperation < TotalOperations) && (!ABORTpressed) )
 	{
-		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>"+tr("Now performing task")+"	: <b>" + Operation[currentOperation] -> GetName() +
-				"</b>";
+		if (ExecuteBefore)
+			nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
+					"</font></b><br>"+tr("pre-task execution of command")+"	: <b>" +
+					Operation[currentOperation] -> GetExecuteBeforeListItem(currentBefore) + "</b>";
 
-		if (DryRun)
-			nowDoingText.append(" <b><font color=magenta>(" + tr("simulation mode") + ")</font>");
+		if (ExecuteAfter)
+			nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
+					"</font></b><br>"+tr("post-task execution of command")+"	: <b>" +
+					Operation[currentOperation] -> GetExecuteAfterListItem(currentAfter) + "</b>";
 
-		nowDoingText.append("</p>");
-		nowDoingText.append(tr("Directory")+" A	: <b><font color=blue>" + dirA +
-				"</font></b><br>"+tr("Directory")+" B	: <b><font color=blue>" + dirB + "</font></b><br>");
-		
-		if (calculating)
-			nowDoingText.append(tr("calculating")+": " + outputString);
-		if (transfering)
-			nowDoingText.append(tr("transfering files")+": " + outputString);
-		if (deleting)
-			nowDoingText.append(tr("deleting files")+": " + outputString);
+		if ( (sync) && (!ExecuteAfter) && (!ExecuteBefore) )	//if a sync operation is executed
+		{
+			nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
+					"</font></b><br>"+tr("Now performing task")+"	: <b>" + Operation[currentOperation] -> GetName() +
+					"</b>";
+
+			if (DryRun)
+				nowDoingText.append(" <b><font color=magenta>(" + tr("simulation mode") + ")</font>");
+
+			nowDoingText.append("</p>");
+			nowDoingText.append(tr("Directory")+" A	: <b><font color=blue>" + dirA +
+					"</font></b><br>"+tr("Directory")+" B	: <b><font color=blue>" + dirB + "</font></b><br>");
+			
+			if (calculating)
+				nowDoingText.append(tr("calculating","info message displayed during ...calculations")+": " + outputString);
+			if (transferring)
+				nowDoingText.append(tr("transferring files","info message displayed during ...file transfers")+": " + outputString);
+			if (deleting)
+				nowDoingText.append(tr("deleting files","info message displayed during ...file deletions")+": " + outputString);
+		}
+
+		if ( (!sync) && (!ExecuteAfter) && (!ExecuteBefore) ) //if a backup operation is executed
+		{
+			nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
+					"</font></b><br>"+tr("Now performing task")+"	: <b>" + Operation[currentOperation] -> GetName() +
+					"</b>";
+
+			if (DryRun)
+				nowDoingText.append(" <b><font color=magenta>(" + tr("simulation mode") + ")</font>");
+
+			nowDoingText.append("</p>");
+			nowDoingText.append(tr("Source")+"	: <b><font color=blue>" + dirA +
+					"</font></b><br>"+tr("Destination")+"	: <b><font color=blue>" + dirB + "</font></b><br>");
+
+			if (calculating)
+				nowDoingText.append(tr("calculating")+": " + outputString);
+			if (transferring)
+				nowDoingText.append(tr("transferring files")+": " + outputString);
+			if (deleting)
+				nowDoingText.append(tr("deleting files")+": " + outputString);
+		}
 	}
-
-	if ( (!sync) && (currentOperation < TotalOperations) && (!ExecuteAfter) && (!ExecuteBefore) ) //if a backup operation is executed
-	{
-		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>"+tr("Now performing task")+"	: <b>" + Operation[currentOperation] -> GetName() +
-				"</b>";
-
-		if (DryRun)
-			nowDoingText.append(" <b><font color=magenta>(" + tr("simulation mode") + ")</font>");
-
-		nowDoingText.append("</p>");
-		nowDoingText.append(tr("Source")+"	: <b><font color=blue>" + dirA +
-				"</font></b><br>"+tr("Destination")+"	: <b><font color=blue>" + dirB + "</font></b><br>");
-
-		if (calculating)
-			nowDoingText.append(tr("calculating")+": " + outputString);
-		if (transfering)
-			nowDoingText.append(tr("transfering files")+": " + outputString);
-		if (deleting)
-			nowDoingText.append(tr("deleting files")+": " + outputString);
-	}
-
-	if (currentOperation == TotalOperations)	//if all operations finished
+	if ( (currentOperation == TotalOperations) && (!ABORTpressed))	//if all operations finished normally - not aborted
 	{
 		NOWexecuting = FALSE;		//this is mainly used if the window close button (or alt+F4) is pressed
 
 		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>====================================================="
+				"</font></b><br>========================================="
 				"<b><br><font color=blue>"+tr("All tasks completed")+" </font></b>";
 		trayMessage =	tr("All tasks completed");
 		if (DryRun)
@@ -614,9 +821,10 @@ void luckyBackupWindow::setNowDoing()
 		}
 		if (!DryRun)
 			nowDoingText.append(tr("logfile(s) have been created under directory: ")+ logDir +"<br>");
-		nowDoingText.append("=====================================================</p>");
-		ui.AbortButton -> setText (tr("Done"));
-		ui.AbortButton -> setIcon(QIcon(":/luckyPrefix/okay.png"));
+		nowDoingText.append("=========================================</p>");
+		ui.AbortButton -> setVisible (FALSE);
+		ui.DoneButton -> setVisible (TRUE);
+		ui.pushButton_minimizeToTray	-> setVisible (FALSE);
 		
 		//update tray baloon
 		if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
@@ -626,16 +834,7 @@ void luckyBackupWindow::setNowDoing()
 			actionAbort	-> setVisible(FALSE);
 		}
 
-		if (!DryRun)
-		{
-			//save the profile to update last execution times & no oferrors
-			if (!saveProfile(currentProfile))
-				savedProfile = FALSE;
-			else
-				savedProfile = TRUE;			//change profile status to "saved"
-			
-			logfile.close();			// close the logfile
-		}
+		finishUp();
 		
 		if ( (silentMode) && (isMinimizedToTray == TRUE) )		// if --silent is given as argument and the gui is not shown exit the app
 		{
@@ -650,19 +849,21 @@ void luckyBackupWindow::setNowDoing()
 			exit(0);	//quit
 		}
 	}
-	if (currentOperation == TotalOperations+2)	//if operations were terminated by user
+	if (ABORTpressed)	//if operations were terminated by user
 	{
 		NOWexecuting = FALSE;		//this is mainly used if the window close button (or alt+F4) is pressed
 		nowDoingText = 	"<p align=\"center\">"+tr("Elapsed time")+" : <b><font color=red>" + DifTime.toString("hh:mm:ss") +
-				"</font></b><br>====================================================="
+				"</font></b><br>========================================="
 				"<br><b><font color=blue>"+tr("Execution of tasks were terminated violently by user")+"</font></b><br>";
 		trayMessage = 	tr("Execution of tasks were terminated violently by user");
 		
 		if (!DryRun)
 			nowDoingText.append(tr("logfile(s) have been created under directory: ")+ logDir +"<br>");
-		nowDoingText.append("=====================================================</p>");
-		ui.AbortButton -> setText (tr("Done"));
-		ui.AbortButton -> setIcon(QIcon(":/luckyPrefix/okay.png"));
+		nowDoingText.append("=========================================</p>");
+		ui.AbortButton -> setVisible (FALSE);
+		ui.DoneButton -> setVisible (TRUE);
+		ui.pushButton_minimizeToTray	-> setVisible (FALSE);
+		ui.rsyncOutput->append("<br><font color=red><b>" + tr("ABORTED") + " !!</b></font>");
 		
 		//update tray baloon
 		if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
@@ -678,15 +879,31 @@ void luckyBackupWindow::setNowDoing()
 			ui.pushButton_nextError	-> setEnabled (TRUE);
 		}
 
+		finishUp();
 		if (!DryRun)
 		{
-			//save the profile to update last execution times & no oferrors
-			if (!saveProfile(currentProfile))
-				savedProfile = FALSE;
-			else
-				savedProfile = TRUE;			//change profile status to "saved"
-				
-			logfile.close();			// close the logfile
+			// strip unused lines from the snapshot changes file ~~~~~~~~~~~~~~~~~~~~~~~~~~~~`
+			QString filesAdded = "", snapLine = "";
+			if (snapfile.open(QIODevice::ReadOnly | QIODevice::Text))
+			{
+				QTextStream in(&snapfile);
+				while (!in.atEnd())
+				{
+					snapLine = in.readLine();
+					if (snapLine.contains("+++++++", Qt::CaseInsensitive))
+					{
+						snapLine = snapLine.right(snapLine.size()-snapLine.lastIndexOf("[LB]")-removeCharLimit) + "\n";
+						filesAdded.append(snapLine);
+					}
+				}
+				snapfile.close();
+			}
+			if (snapfile.open(QIODevice::WriteOnly))
+			{
+				QTextStream out(&snapfile);
+				out << filesAdded;
+				snapfile.close();
+			}
 		}
 		
 		if ( (silentMode) && (isMinimizedToTray == TRUE) )		// if --silent is given as argument and the gui is not shown, exit the app
@@ -695,6 +912,21 @@ void luckyBackupWindow::setNowDoing()
 	ui.nowDoing -> setText (nowDoingText);
  }
 
+// function finishUp=====================================================================================================
+// finish up some stuff when all tasks finish either normally or aborted
+void luckyBackupWindow::finishUp()
+{
+	if (!DryRun)
+	{
+		//save the profile to update last execution times & no of errors
+		if (!saveProfile(currentProfile))
+			savedProfile = FALSE;
+		else
+			savedProfile = TRUE;			//change profile status to "saved"
+			
+		logfile.close();			// close the logfile
+	}
+}
 // previous error button pressed=====================================================================================================
 void luckyBackupWindow::previousErrorJump()
 {
