@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 10 Dec 2009
+//  last modified 	: 10 Jun 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -34,6 +34,7 @@ void luckyBackupWindow::InitializeVariables()
 	TotalOperations = 0;
 	currentOperation=-1;
 	NOWexecuting = FALSE;
+	guiModeNormal = TRUE;
 	modifyOK = FALSE;
 	savedProfile = TRUE;
 	taskClicked = FALSE;	
@@ -42,12 +43,15 @@ void luckyBackupWindow::InitializeVariables()
 	InfoData = "";
 	InfoInt = 0;
 	defaultLanguage = "en";
-	mainWindowWidth = 580;
-	mainWindowHeight = 560;
-	AreToolbarsLocked = FALSE;
+	mainWindowWidth = 615;
+	mainWindowHeight = 500;
+	AreToolbarsLocked = TRUE;
 	IsVisibleProfileComboToolbar = TRUE;
 	IsVisibleProfileToolbar = TRUE;
+	IsVisibleProfileStartToolbar = TRUE;
 	IsVisibleToolbarText = FALSE;
+	IsVisibleInfoWindow = TRUE;
+	validation = FALSE;
 
 	// translations --------------------------------
 	TransDir = "";
@@ -92,29 +96,42 @@ void luckyBackupWindow::InitializeVariables()
 		licenseURL.setUrl(relativeLicense);
 }
 
+
 // retranslateUi ===================================================================================================================================
 // retranslate the ui every time the user chooses a different language from the menu
 void luckyBackupWindow::retranslateUi()
 {
 	ui.menuFile 		-> setTitle(tr("&Profile","This is a top menu item"));
-	ui.actionRefresh	-> setText(tr("&Refresh","This is a top menu action"));
-	ui.actionDefault	-> setText(tr("De&fault","This is a top menu action"));
-	ui.actionDefault	-> setToolTip(tr("Set as Default","This is a top menu action tooltip"));
-	ui.actionRename		-> setText(tr("R&ename","This is a top menu action"));
-	ui.actionDelete		-> setText(tr("&Delete","This is a top menu action"));
-	ui.actionNew 		-> setText(tr("&New","This is a top menu action"));
-	ui.actionSave 		-> setText(tr("&Save","This is a top menu action"));
-	ui.actionExport		-> setText(tr("E&xport","This is a top menu action"));
-	ui.actionImport		-> setText(tr("&Import","This is a top menu action"));
-	ui.actionSchedule 	-> setText(tr("S&chedule","This is a top menu action"));
-	ui.actionQuit 		-> setText(tr("&Quit","This is a top menu action"));
+	ui.actionRefresh	-> setText(tr("&Refresh","This is a top 'Profile' menu action"));
+	ui.actionDefault	-> setText(tr("De&fault","This is a top 'Profile' menu action"));
+	ui.actionDefault	-> setToolTip(tr("Set as Default","This is a top 'Profile' menu action tooltip"));
+	ui.actionRename		-> setText(tr("R&ename","This is a top 'Profile' menu action"));
+	ui.actionDelete		-> setText(tr("&Delete","This is a top 'Profile' menu action"));
+	ui.actionNew 		-> setText(tr("&New","This is a top 'Profile' menu action"));
+	ui.actionSave 		-> setText(tr("&Save","This is a top 'Profile' menu action"));
+	ui.actionExport		-> setText(tr("E&xport","This is a top 'Profile' menu action"));
+	ui.actionImport		-> setText(tr("&Import","This is a top 'Profile' menu action"));
+	ui.actionSchedule 	-> setText(tr("S&chedule","This is a top 'Profile' menu action"));
+	ui.actionQuit 		-> setText(tr("&Quit","This is a top 'Profile' menu action"));
+	ui.actionDuplicate_Profile -> setText(tr("D&uplicate","This is a top 'Profile' menu action"));
+	
+	ui.menu_Task		-> setTitle(tr("&Task","This is a top menu action"));
+	ui.action_TaskAdd	-> setText(tr("&Add","This is a top 'Task' menu action"));
+	ui.action_TaskRemove	-> setText(tr("&Remove","This is a top 'Task' menu action"));
+	ui.action_TaskModify	-> setText(tr("&Modify","This is a top 'Task' menu action"));
+	ui.action_TaskDuplicate	-> setText(tr("Create D&uplicate task","This is a top 'Task' menu action"));
+	ui.action_TaskCreateRestore -> setText(tr("Create R&estore task","This is a top 'Task' menu action"));
+	ui.action_TaskManageBackup -> setText(tr("Manage &Backup","This is a top 'Task' menu action"));
+	ui.action_TaskManageBackup -> setToolTip(tr("display - restore - delete existing backups of highlighted task",
+						    "This is a top 'Task' menu action tooltip"));
 
 	settingsMenu	-> setTitle(tr("&Settings","This is a top menu item"));
-	visibleProfileToolbar -> setText(tr("Show Actions Toolbar","This is a top menu action"));
-	visibleProfileComboToolbar -> setText(tr("Show Current Profile","This is a top menu action"));
-	actionLockToolbars -> setText(tr("Lock Toolbars","This is a top menu action"));
-	actionVisibleToolbarText -> setText(tr("Show labels under toolbar icons","This is a top menu action"));
+	visibleProfileToolbar -> setText(tr("Actions","This is a top menu action"));
+	visibleProfileComboToolbar -> setText(tr("Current Profile","This is a top menu action"));
+	actionLockToolbars -> setText(tr("Lock","This is a top menu action. Refers to toolbars"));
+	actionVisibleToolbarText -> setText(tr("Show text under icons","This is a top menu action"));
 	languageMenu	-> setTitle(tr("&Language","This is a top menu item"));
+	toolbarsMenu	-> setTitle(tr("&Toolbars","This is a top menu item"));
 
 	helpMenu	-> setTitle(tr("&Help","This is a top menu item"));
 	actionHelp	-> setText(appName + " " + tr("&Handbook","full phrase: 'luckyBackup Handbook'"));
@@ -137,19 +154,25 @@ void luckyBackupWindow::retranslateUi()
 	ui.pushButton_remove -> setText(tr("remove","remove task button label"));
 	ui.pushButton_remove -> setToolTip(tr("remove highlighted task","remove task button tooltip"));
 	ui.pushButton_edit -> setText(tr("modify","modify task button label"));
-	ui.pushButton_edit -> setToolTip(tr("modify highlighted task","modify task button tooltip"));
-	ui.pushButton_manage -> setText(tr("manage backup","manage task button label"));
-	ui.pushButton_manage -> setToolTip(tr("display - restore - delete existing backups of highlighted task","manage task button tooltip"));
+	ui.pushButton_edit -> setToolTip(tr("modify highlighted task","modify task button tooltip"));	
 
-	ui.groupBox_operations -> setTitle(tr("Run","run groupbox label"));
-	ui.pushButton_start -> setText(tr("Start","start button label"));
+	//ui.groupBox_operations -> setTitle(tr("Run","run groupbox label"));
+	ui.pushButton_start -> setText(tr("Run","start button label"));
 	ui.pushButton_start -> setToolTip(tr("Begin the execution of all included tasks","start button tooltip"));
-	ui.checkBox_DryRun -> setText(tr("simulation","simulation checkbox label"));
-	ui.checkBox_DryRun -> setToolTip(tr("This makes rsync perform a <b>trial run</b> that doesn't make any changes (and produces mostly the same output as a real run)","simulation checkbox tooltip - line1")+".<br>"+tr("NOTE","simulation checkbox tooltip - line2")+": "+tr("Progressbar update will not be realistic","simulation checkbox tooltip - line2"));
+	ui.AbortButton  -> setText(tr("Abort","Abort button label"));
+	ui.AbortButton -> setToolTip(tr("Stop the execution of running tasks NOW","Abort button tooltip"));
+	ui.DoneButton -> setText (tr("Done"));
+	ui.DoneButton -> setToolTip(tr("Execution of tasks finished","Done button tooltip"));
+	ui.checkBox_DryRun -> setText(tr("Dry","simulation checkbox label. Translate this as 'simulation'"));
+	ui.checkBox_DryRun -> setToolTip(tr("This will perform a <b>simulation run</b> that doesn't make any changes (and produces mostly the same output as a real run)","simulation checkbox tooltip - line1. Please leave tags <b> and </b> intact and surrounding 'simulation run'")+".<br>"+tr("NOTE","simulation checkbox tooltip - line2")+": "+tr("Progressbar update will not be realistic","simulation checkbox tooltip - line2"));
 
 	ui.label_InformationWindow -> setText(tr("Information window","information window title"));
 	ui.pushButton_exit -> setToolTip(tr("Exit","exit button tooltip. full phrase is: 'exit luckybackup'")+" "+appName);
 	ui.pushButton_exit -> setText(tr("EXIT","EXIT button label"));
+	if (IsVisibleInfoWindow)
+		ui.pushButton_InfoCollapse -> setToolTip(tr("Hide information window","show/hide information window button tooltip"));
+	else
+		ui.pushButton_InfoCollapse -> setToolTip(tr("Show information window","show/hide information window button tooltip"));
 	
 	ui.pushButton_minimizeToTray -> setText(tr("minimize to tray"));
 	ui.pushButton_minimizeToTray -> setToolTip(tr("minimizes the window to the tray area"));
@@ -197,6 +220,7 @@ void luckyBackupWindow::createActions()
 	actionHelp = new QAction(QIcon(":/luckyPrefix/book.png"), "Handbook", this);
 	actionHelp -> setShortcut(tr("F1"));
 	actionAbout = new QAction(QIcon(":/luckyPrefix/about.png"), "About", this);
+	
 	actionLockToolbars = new QAction("Lock Toolbars",this);
 	actionLockToolbars -> setCheckable(TRUE);
 	actionLockToolbars -> setChecked(AreToolbarsLocked);
@@ -224,12 +248,16 @@ void luckyBackupWindow::createMenus()
 	helpMenu -> addAction(actionAbout);
 
 	// toolbars actions -------------------------------------------------------------------------------
+	toolbarsGroup = new QActionGroup(this);
+	toolbarsMenu = settingsMenu -> addMenu("");
+	
 	visibleProfileComboToolbar = profileComboToolbar->toggleViewAction();
-	settingsMenu -> addAction(visibleProfileComboToolbar);
+	toolbarsMenu -> addAction(visibleProfileComboToolbar);
 	visibleProfileToolbar = profileToolbar->toggleViewAction();
-	settingsMenu -> addAction(visibleProfileToolbar);
-	settingsMenu -> addAction(actionLockToolbars);
-	settingsMenu -> addAction(actionVisibleToolbarText);
+	toolbarsMenu -> addAction(visibleProfileToolbar);
+	toolbarsMenu -> addSeparator();
+	toolbarsMenu -> addAction(actionLockToolbars);
+	toolbarsMenu -> addAction(actionVisibleToolbarText);
 	settingsMenu -> addSeparator();
 
 	// language sub-menu -------------------------------------------------------------------------------
@@ -263,31 +291,41 @@ void luckyBackupWindow::createMenus()
 	}
 }
 // createToolbar =============================================================================================================================
-// create the tool bar
+// create the tool bars
 void luckyBackupWindow::createToolbar()
 {
 	profileComboToolbar = new QToolBar("current profile", this);
 	profileToolbar = new QToolBar("actions", this);
+	profileStartToolbar = new QToolBar("start", this);
 	this -> addToolBar(Qt::TopToolBarArea, profileComboToolbar);
 	this -> addToolBar(Qt::TopToolBarArea, profileToolbar);
+	this -> addToolBar(Qt::TopToolBarArea, profileStartToolbar);
 
-	QSize ToolbarIconSize(24,24);
+	QSize ToolbarIconSize(22,22);
 	profileToolbar -> setIconSize(ToolbarIconSize);
 
+	//Profile-------------------------------------------------------------------
 	profileComboToolbar -> addWidget(ui.comboBox_profile);	//profile drop-down list
-//	profileToolbar -> addSeparator();
+	
+	//Start & simulation buttons-------------------------------------------------------------------
+	profileStartToolbar -> addWidget(ui.groupBox_operations);//profile start toolbar
+	
+	//Profile Actions-------------------------------------------------------------------
+	profileToolbar -> addSeparator();			//---seperator---
 	profileToolbar -> addAction(ui.actionSave);		//save
-	profileToolbar -> addAction(ui.actionDefault);		//default
-	profileToolbar -> addAction(ui.actionRename);		//rename
+//	profileToolbar -> addAction(ui.actionDefault);		//default
+//	profileToolbar -> addAction(ui.actionRename);		//rename
+	profileToolbar -> addAction(ui.actionNew);		//new
 	profileToolbar -> addAction(ui.actionDelete);		//delete
 //	profileToolbar -> addSeparator();
-	profileToolbar -> addAction(ui.actionNew);		//new
-
 //	profileToolbar -> addAction(ui.actionExport);
 //	profileToolbar -> addAction(ui.actionImport);
 	profileToolbar -> addSeparator();			//---seperator---
 	profileToolbar -> addAction(ui.actionSchedule);		//schedule
 	profileToolbar -> addAction(ui.actionRefresh);		//refresh
+	profileToolbar -> addSeparator();			//---seperator---
+	profileToolbar -> addAction(ui.actionQuit);		//quit
+	profileToolbar -> addSeparator();			//---seperator---
 
 	profileComboToolbar -> setVisible (IsVisibleProfileComboToolbar);
 	profileToolbar -> setVisible (IsVisibleProfileToolbar);
@@ -295,67 +333,6 @@ void luckyBackupWindow::createToolbar()
 }
 
 
-// AlsoCreateRestore ================================================================================================================================
-//function to create another operation for RESTORE
-void luckyBackupWindow::AlsoCreateRestore()
-{
-	int oldCurrentOperation = currentOperation;
-	TotalOperations = ui.listWidget_operations -> count();		//Get the Operations list size
-	currentOperation = TotalOperations;
-	
-	//Create a new array item identical to the one just created
-	operation *tempOp = new operation;
-	*tempOp = *Operation[oldCurrentOperation];
-	Operation[currentOperation] = tempOp;	
-
-	//Change its name, source, destination, alsocreate checkbox, update checkbox, Remote Host radiobuttons
-	Operation[oldCurrentOperation] -> SetAlsoCreateRestore(FALSE);
-	Operation[currentOperation] -> SetName ("RESTORE - " + (Operation[currentOperation] -> GetName()));
-	Operation[currentOperation] -> SetAlsoCreateRestore(FALSE);
-	Operation[currentOperation] -> SetOptionsUpdate(FALSE);
-	Operation[currentOperation] -> SetRemoteDestination(Operation[oldCurrentOperation]-> GetRemoteSource());
-	Operation[currentOperation] -> SetRemoteSource(Operation[oldCurrentOperation]-> GetRemoteDestination());
-	QString sourceDir	= Operation[oldCurrentOperation] -> GetDestination();
-	QString destDir		= Operation[oldCurrentOperation] -> GetSource();
-
-	if (Operation[currentOperation] -> GetTypeDirName())
-	{
-		sourceDir.append(destDir.right(destDir.size() - destDir.lastIndexOf("/") - 1));
-		destDir.chop(destDir.size() - destDir.lastIndexOf("/") - 1);
-	}
-
-	Operation[currentOperation] -> SetSource (sourceDir);
-	Operation[currentOperation] -> SetDestination (destDir);
-
-	//add a new item in the operations list
-	ui.listWidget_operations -> addItem( Operation[currentOperation] -> GetName() );
-	ui.listWidget_operations -> setCurrentRow(currentOperation);
-	ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
-	TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
-
-	QMessageBox::warning(this, appName,
-		tr("You have asked for a RESTORE task to be created","'create restore' message line 1/4")+"<br><br>"+
-		tr("Please have a good look at the following task properties dialog","'create restore' message line 2/4")+" <br>"+
-		tr("and change anything you wish before proceeding","'create restore' message line 3/4")+" <br><br>"+
-		tr("Especially check 'Task name', 'source', 'destination' & 'skip newer destination files' checkbox (advanced)","'create restore' message line 4/4")+"<br>",
-		QMessageBox::Ok | QMessageBox::Default);
-	modifyConnected = TRUE;
-	modify();	//open the modify dialog for the new operation to make sure everything is ok
-
-	if (modifyOK)		//connect the operation with its RESTORE duplicate
-	{
-		Operation[currentOperation] -> SetConnectRestore(Operation[oldCurrentOperation] -> GetName());	
-		Operation[oldCurrentOperation] -> SetConnectRestore(Operation[currentOperation] -> GetName());
-		savedProfile = FALSE;			//change profile status to "unsaved"
-	}
-	else
-	{
-		//remove already created RESTORE operation from operations list
-		ui.listWidget_operations -> takeItem(currentOperation);		//take out the selected item from the list
-		TotalOperations = ui.listWidget_operations -> count();		//TotalOperations takes the new value (old - 1)
-	}
-}
-
 
 // checkOperationsList===============================================================================================================================
 // Checks if the Operations list is ok to proceed
@@ -368,7 +345,11 @@ bool luckyBackupWindow::checkOperationList()
 	{
 		message.prepend("<font color=red><b>" + tr("ERROR") + "</b></font><br>");
 		if (showBox)
-			QMessageBox::critical(this, appName,message, QMessageBox::Ok | QMessageBox::Default);
+		{
+			textDialog textdialogC ("QtCritical", message, this);
+			textdialogC.exec();
+		}
+		
 		ui.textBrowser_info -> setText(message);
 		return FALSE;
 	}
@@ -377,9 +358,11 @@ bool luckyBackupWindow::checkOperationList()
 
 //checkDeclared ===================================================================================================================================
 //Check if the declared data are ok by calling checkBackupDirs, checkSyncDirs accordingly
+//This is called from the gui
 void luckyBackupWindow::checkDeclared()
 {
-	checkDeclaredDirs();
+	int currentSelection = ui.listWidget_operations -> currentRow();	//keep the current selection
+	checkDeclaredDirs(TRUE);
 
 	currentOperation = 0;
 	CheckedData = "";
@@ -404,6 +387,12 @@ void luckyBackupWindow::checkDeclared()
 			ui.listWidget_operations -> currentItem() -> setIcon(QIcon(":/luckyPrefix/about.png"));	
 		currentOperation++;
 	}
+	
+	if (currentSelection > -1)		// re-select the current selection (don't leave the last task selected)
+	{
+		currentOperation = currentSelection;
+		ui.listWidget_operations -> setCurrentRow(currentOperation);
+	}
 }
 
 // setCurrentprofile ================================================================================================================================
@@ -579,22 +568,22 @@ int luckyBackupWindow::isProfileSaved()
 {
 	if (!savedProfile)	//if the current profile is not saved, ask the user if he/she wants to, before proceeding
 	{
-		int r = QMessageBox::question(this, appName,
-				tr("Profile","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+" <b>" + profileName + "</b> " +tr("is modified","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+ ".<br><br>" +
-				tr("Would you like to save it before proceeding ?"),
-				QMessageBox::Yes | QMessageBox::Default,
-				QMessageBox::No | QMessageBox::Escape);
-		if ( r == QMessageBox::Yes )		//if user answers yes
+		textDialog textdialogQ ("QtQuestion",
+					tr("Profile","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+" <b>" + profileName + "</b> " +
+					tr("is modified","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")+ ".<br><br>" +
+					tr("Would you like to save it before proceeding ?"), this);
+		textdialogQ.exec();
+		
+		if (textdialogQ.getGoOn() > 0)		//if user answers yes
 		{
 			if (!saveCurrentProfile())	// if it cannot be saved for any reason pop up a yes/no message box to go on or not
 			{
-				int r2 = QMessageBox::warning(this, appName,
+				textDialog textdialogQ2 ("QtQuestion",
 					tr("Profile","Information window message. Full phrase: 'profile <PROFILENAME> could not be saved'")+" <b>" + profileName + "</b> " +tr("could not be saved","Information window message. Full phrase: 'profile <PROFILENAME> is modified'")
 						+"<br><font color=red>"+ profile.errorString()
-						+ "</font><br><br>" + tr("Would you like to proceed anyway?"),
-					QMessageBox::Yes | QMessageBox::Default,
-					QMessageBox::No | QMessageBox::Escape);
-				if ( r2 == QMessageBox::No )
+						+ "</font><br><br>" + tr("Would you like to proceed anyway?"), this);
+				textdialogQ2.exec();
+				if (textdialogQ2.getGoOn() == 0)		//if user answers no
 				{
 					int previousIndex = ui.comboBox_profile -> findText (profileName, Qt::MatchExactly);
 					GoBack = TRUE;	// the next line will execute  function profileComboChanged again. set TRUE to avoid that
@@ -638,6 +627,7 @@ bool luckyBackupWindow::saveSettings()
 	v = "Is_toolbarText_visible";	out << v;	v = IsVisibleToolbarText;	out << v;	//output the visible state of toolbar text
 	v = "Default_Profile";		out << v;	v = defaultProfile;	out << v;	//output the default profile full path
 	v = "Default_Language";		out << v;	v = defaultLanguage;	out << v;	//output the default language
+	v = "Visible_info_window";	out << v;	v = IsVisibleInfoWindow;out << v;	//output the visibility state of the info window
 	v = "Settings_file_end";	out << v;	
 
 	settingsfile.close();
@@ -676,8 +666,8 @@ bool luckyBackupWindow::loadSettings()
 		settingsfile.close();
 		return FALSE;
 	}
-	
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+/*	
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 	//this is used for upgrade from 0.3.3 version - TAKE IT OUT at later versions !!!
 	if ( (tempAppVersion < appVersion) && (tempAppVersion < 0.34) )
 		QMessageBox::warning(this, appName,
@@ -685,8 +675,8 @@ bool luckyBackupWindow::loadSettings()
 				tr("Due to code improvements regarding the scheduling function, there is no backward compatibility") +"<br><br><b>" +
 				tr("Please re-define your schedules, if any") +"...</b>",
 				QMessageBox::Ok | QMessageBox::Default);
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+*/
 
 	in>>v;	vString = v.toString();	in >> v;	//input a label in vString and real data in v
 	while (vString != "Settings_file_end")
@@ -699,6 +689,7 @@ bool luckyBackupWindow::loadSettings()
 		if (vString == "Is_toolbarText_visible")	IsVisibleToolbarText = v.toBool();
 		if (vString == "Default_Profile")		defaultProfile = v.toString();
 		if (vString == "Default_Language")		defaultLanguage = v.toString();
+		if (vString == "Visible_info_window")		IsVisibleInfoWindow = v.toBool();
 
 		in>>v;	vString = v.toString();
 		if (vString!="Settings_file_end")
