@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 24 Nov 2009
+ last modified 		: 14 Jun 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -35,7 +35,7 @@
 QString myHome = QDir::homePath();				// user's home directory
 QString currentUser;						// will hold the current username (definition at luckybackupwindow.cpp)
 QString const appName = "luckyBackup";				// application name
-double const appVersion = 0.35;					// application version
+double const appVersion = 0.41;					// application version
 double const validProfileVersion = 0.21;			// profile version before this a profile won't be loaded
 double const validScheduleVersion = 0.34;			// schedule version before this a schedule won't be loaded
 double const validSettingsVersion = 0.3;			// Settings file valid version
@@ -46,7 +46,11 @@ QString defaultProfile = profileDir + "default.profile"; 	// default profile
 QString standardDefaultProfile = profileDir + "default.profile"; // standard default profile
 QString logDir = luckyBackupDir + "logs/";			// logs directory
 QString logfilename = logDir + "logfile.log";			// logfile filename - this will change according to the profile an task executed
-QString cronlogfilename = logDir + "cronLogfile.log";		// cron logfile filename
+QString cronlogString = "LastCronLog.log";				// cron logfile full filename: "ProfileName-LastCronLog.log"
+QString snapDefaultDir = ".luckybackup-snaphots/";		// This is the directory where snapshots are placed. It lies inside the destination
+QString snapChangesDir = luckyBackupDir + "snaps/";		// Snapshots changes files are stored here. It lies inside ~
+QString snapchangesfilename = snapChangesDir + "changes.log";	// Snapshot changes filename. This will change according to the snapshot
+QString snapChangesString = "[changed_data]%i[LB]%n";		// The log lines format of the "changes" file that stores changes made for every snapshot
 QString scheduleDir = luckyBackupDir + "schedule/";		// schedule directory
 QString schedulefilename = scheduleDir + "schedule.dat";	// cron data filename
 QString cronfilename = scheduleDir + "luckyCron.txt";		// cron filename
@@ -72,6 +76,7 @@ int errorsFound;						//count errors when executing rync or pre/post command
 int const maxOperations = 100;		//The maximum number or operations permitted
 int TotalOperations=0;			//The number of available operations "operations list"- starts from 1
 int currentOperation=-1;		//this holds the current row from the operations list- starts from 0
+int removeCharLimit;			// No of characters to remove from lines inside snapshot .changes file
 bool modifyOK=FALSE;			//bool variable that says create or modify opeartion went ok
 bool modifyConnected=FALSE;		//if the operation under modification is connected to another op, this becomes TRUE
 bool DryRun=FALSE;			//shows if dry-run is checked
@@ -84,6 +89,7 @@ QString currentProfile="";		// This holds the filename of the currently used pro
 QString profileName="";			//just holds the profile name not the full path+filename.profile
 QFile profile("");			//this is the profile QFile
 QFile logfile("");			//this is the logfile QFile
+QFile snapfile("");			//this is the snapshot changes QFile
 QString CheckedData;			//String holding the current task message (OK - WARNING - CRITICAL) for info window display
 QString CheckedDataCLI;			//String holding the current task message (OK - WARNING - CRITICAL) for CLI  display
 operation *Operation[maxOperations];	//The array that holds name, source, destination & arguments of "Opereations list"
@@ -93,6 +99,7 @@ bool NoQuestions;	// do not ask any questions at console mode
 bool SkipCritical;	// skip critical tasks
 bool silentMode;	// start at silent mode
 bool runImmediately;	// execute a profile immediately after gui loads
+bool validation;	//becomes true if "validation check" button is pressed
 
 // functions ------------------------------------------------------------------------------------------------------------------------
 bool argumentsTest(int , char**);	// checks the arguments given at command-line and returns true if everything is ok
@@ -106,7 +113,7 @@ void checkBackupDirs(QString, QString);	// function to check if the source & des
 int loadProfile(QString);		// loads an existing profile
 bool saveProfile(QString);		// saves an existing profile
 bool checkTaskList();			// Checks if the Task list is ok to proceed
-bool checkDeclaredDirs();		// Check if the declared data are ok by calling checkBackupDirs or checkSyncDirs
+bool checkDeclaredDirs(bool);		// Check if the declared data are ok by calling checkBackupDirs or checkSyncDirs
 QStringList AppendArguments(operation*);// Set command's (normally rsync) arguments
 bool writeToLog;			//if the log file is ok to write this becomes TRUE
 QString logFileUpdate(QString, QString, int);		// Update the logfile with some string
