@@ -4,7 +4,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 ===============================================================================================================================
 ===============================================================================================================================
     This file is part of "luckyBackup" project
-    Copyright 2008-2009, Loukas Avgeriou
+    Copyright 2008-2010, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 project version	: Please see "main.cpp" for project version
 
 developer 	: luckyb 
-last modified 	: 17 Dec 2009
+last modified 	: 12 Jun 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -46,6 +46,7 @@ last modified 	: 17 Dec 2009
 #include "executenow.cpp"
 #include "patternEditor.cpp"
 
+helpBrowser *helpbrowser;
 
 //class luckyBackupWindow constructor=============================================================================================
 luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
@@ -54,14 +55,16 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 
 	InitializeVariables();
 
-	//create directory ~/.luckyBackup including folders "logs", "profiles" & "schedule" if it does not exist for the current user
-	QDir profiledir(profileDir), logdir(logDir), scheduledir(scheduleDir);
+	//create directory ~/.luckyBackup including folders "logs", "profiles", "schedule", snaps if they do not exist for the current user
+	QDir profiledir(profileDir), logdir(logDir), scheduledir(scheduleDir), snapdir(snapChangesDir);
 	if (!profiledir.exists())
 		profiledir.mkpath(profileDir);
 	if (!logdir.exists())
 		logdir.mkpath(logDir);
 	if (!scheduledir.exists())
 		scheduledir.mkpath(scheduleDir);
+	if (!snapdir.exists())
+		snapdir.mkpath(snapChangesDir);
 	currentUser = myHome;
 	if (currentUser == "/root")
 	{
@@ -98,7 +101,7 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect( ui.comboBox_profile, SIGNAL(currentIndexChanged (const int) ), this, SLOT(profileComboChanged()));
 
 	connect( ui.actionNew, SIGNAL(triggered()), this, SLOT(NewProfile()));			//menu action newProfile
-	connect( ui.actionRename, SIGNAL(triggered()), this, SLOT(renameCurrentProfile()));			//menu action renameProfile
+	connect( ui.actionRename, SIGNAL(triggered()), this, SLOT(renameCurrentProfile()));	//menu action renameProfile
 	connect( ui.actionSave, SIGNAL(triggered()), this, SLOT(savePressed()));		//menu action saveProfile
 	connect ( ui.actionSchedule, SIGNAL( triggered() ), this, SLOT( schedule() ) );		//action schedule
 	connect ( ui.actionRefresh, SIGNAL( triggered() ), this, SLOT( refreshList() ) );	//action refresh (task list)
@@ -106,11 +109,18 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect ( ui.actionDefault, SIGNAL( triggered() ), this, SLOT( setDefaultProfile() ) );	//action default (set currentProfile as default)
 	connect ( ui.actionImport, SIGNAL( triggered() ), this, SLOT( importProfile() ) );	//action import profile
 	connect ( ui.actionExport, SIGNAL( triggered() ), this, SLOT( exportProfile() ) );	//action export profile
-
+	connect ( ui.actionDuplicate_Profile, SIGNAL( triggered() ), this, SLOT( duplicateProfile() ) ); //action duplicate profile
+	
+	connect ( ui.action_TaskAdd, SIGNAL( triggered() ), this, SLOT( add() ) ); 			//action add task
+	connect ( ui.action_TaskModify, SIGNAL( triggered() ), this, SLOT( modify() ) ); 		//action modify task
+	connect ( ui.action_TaskRemove, SIGNAL( triggered() ), this, SLOT( remove() ) ); 		//action remove task
+	connect ( ui.action_TaskDuplicate, SIGNAL( triggered() ), this, SLOT( duplicateTask() ) ); 	//action create duplicate
+	connect ( ui.action_TaskCreateRestore, SIGNAL( triggered() ), this, SLOT( AlsoCreateRestore() ) ); 	//action create restore
+	connect ( ui.action_TaskManageBackup, SIGNAL( triggered() ), this, SLOT( manage() ) ); 		//action manage backup
+	
 	connect (ui.pushButton_add, SIGNAL (clicked() ), this, SLOT(add()));			//pushbutton create (task)
 	connect (ui.pushButton_edit, SIGNAL (clicked() ), this, SLOT(modify()));		//pushbutton modify (task)
 	connect ( ui.pushButton_remove, SIGNAL( clicked() ), this, SLOT( remove() ) );		//pushbutton remove (task)
-	connect ( ui.pushButton_manage, SIGNAL( clicked() ), this, SLOT( manage() ) );		//pushbutton manage (task)
 	connect ( ui.pushButton_up, SIGNAL( clicked() ), this, SLOT( moveUp() ) );		//pushbutton up
 	connect ( ui.pushButton_down, SIGNAL( clicked() ), this, SLOT( moveDown() ) );		//pushbutton down
 	connect ( ui.pushButton_start, SIGNAL( clicked() ), this, SLOT( start() ) );		//pushbutton start
@@ -121,11 +131,21 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect (ui.pushButton_previousError, SIGNAL (clicked() ), this, SLOT(previousErrorJump()));//pushbutton jump to prev error
 	connect (ui.pushButton_nextError, SIGNAL (clicked() ), this, SLOT(nextErrorJump()));//pushbutton jump to next error
 	
+	connect (ui.pushButton_InfoCollapse, SIGNAL (clicked() ), this, SLOT(hideShowInfoWindow()));//pushbutton hide/show info window
+	
 	// Load the default profile as soon as the app starts or the one given as a command line argument
 	if (!runImmediately)
 		setCurrentProfile(defaultProfile);	// set the defaultProfile as current
+
 	int create = createCurrentProfile();	// if it does not exist create it
-	loadCurrentProfile();			// load the current (default or not ) profile
+
+	loadCurrentProfile();			// load the current (default or not ) profile - this is inside functions.cpp
+
+// *********************Testing purposes message box *********************
+//QMessageBox::information(this, "LB","CurrentProfile=" + currentProfile + "\ntotal tasks: " + countStr.setNum(TotalOperations));
+
+	checkCurrentItem();	//refresh the selected (last) task as well as the menu items that depend on its type (sync/backup)
+
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	InfoData.append("<p align=\"center\"><font color=magenta><b>" + tr("Welcome to","full phrase: 'Welcome to luckyBackup'") +" "
 	+ appName + ", " + currentUser + " :-)</font></b></p>");
@@ -137,12 +157,13 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 
 	if (DryRun)		// if --dry-run was given as an argument, check the relevant box
 		ui.checkBox_DryRun -> setChecked(TRUE);
-	
+
 	if (runImmediately)
 		start();
 	
 	//variable that helps with translations
 	QString currentLanguageIs = tr("English","Do not translate this. Enter here the language of the translation in native characters instead. This is how your translation will appear under the 'language' menu.");
+
 }
 
 //===================================================================================================================================================
@@ -153,12 +174,9 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 // Exits luckybackup. Warn if the profile used is not saved
 void luckyBackupWindow::exitApp()
 {
-	if (NOWexecuting)		//if a profile execution is in progress
+	if (NOWexecuting)		//if a profile execution is in progress just minimize to tray
 	{
-		QMessageBox::warning(this, appName,
-				"<b>" + tr("profile execution in progress")+"...</b> <br><br>" +
-				tr("Please stop it before closing the main application window") + "!!",
-				QMessageBox::Ok | QMessageBox::Default);
+		minimizeTray();
 		return;
 	}
 	if (isProfileSaved() == 0)	//if the current profile is not saved, ask the user if he/she wants to
@@ -167,6 +185,7 @@ void luckyBackupWindow::exitApp()
 	mainWindowHeight = this -> height();
 	IsVisibleProfileComboToolbar = profileComboToolbar -> isVisible();
 	IsVisibleProfileToolbar = profileToolbar -> isVisible();
+	IsVisibleProfileStartToolbar = profileStartToolbar -> isVisible();
 	saveSettings();
 	exit(0);	//quit
 }
@@ -208,6 +227,8 @@ void luckyBackupWindow::setToolbarAttrs()
 {
 	profileComboToolbar -> setFloatable(!actionLockToolbars->isChecked());
 	profileComboToolbar -> setMovable(!actionLockToolbars->isChecked());
+	profileStartToolbar -> setFloatable(!actionLockToolbars->isChecked());
+	profileStartToolbar -> setMovable(!actionLockToolbars->isChecked());
 	profileToolbar -> setFloatable(!actionLockToolbars->isChecked());
 	profileToolbar -> setMovable(!actionLockToolbars->isChecked());
 
@@ -264,9 +285,11 @@ void luckyBackupWindow::NewProfile()
 		message = tr("Profile","full phrase: 'Profile <PROFILENAME> already exists'")+" <b>" + newProfileName + "</b> " +
 			tr("already exists","full phrase: 'Profile <PROFILENAME> already exists'") + "<br>" +
 			tr("Would you like to replace it ?");
-		int r = QMessageBox::question(this, appName,message,QMessageBox::Yes | 
-						QMessageBox::Default,QMessageBox::No | QMessageBox::Escape);
-		if ( r == QMessageBox::Yes )		//if user answers yes
+
+		textDialog textdialogQ ("QtQuestion", message, this);
+		textdialogQ.exec();
+
+		if (textdialogQ.getGoOn() > 0)		//if user answers yes
 		{
 			if (!newprofile.remove())	// delete the old profile or display a message if you can't
 			{
@@ -332,16 +355,18 @@ void luckyBackupWindow::renameCurrentProfile()
 		message = tr("Profile","full phrase: 'Profile <PROFILENAME> already exists'")+" <b>" + newProfileName + "</b> " +
 			tr("already exists","full phrase: 'Profile <PROFILENAME> already exists'") + "<br>" +
 			tr("Would you like to replace it ?");
-		int r = QMessageBox::question(this, appName,message,QMessageBox::Yes | 
-						QMessageBox::Default,QMessageBox::No | QMessageBox::Escape);
-		if ( r == QMessageBox::Yes )		//if user answers yes
+
+		textDialog textdialogQ ("QtQuestion", message, this);
+		textdialogQ.exec();
+
+		if (textdialogQ.getGoOn() > 0)		//if user answers yes
 		{
 			if (!newprofile.remove())	// delete the old profile or display a message if you can't
 			{
 				InfoData = "<font color=red><b>" + tr("ERROR") + "</font></b><br>" +
 					tr("Failed to replace profile",
 					"full phrase: 'Failed to replace profile <PROFILENAME>'")+" <b>" + newProfileName + "</b><br><font color=red>"
-					+ profile.errorString() +"</font>";
+					+ newprofile.errorString() +"</font>";
 				ui.textBrowser_info -> setText(InfoData);	//update the info window
 				return;
 			}
@@ -391,9 +416,10 @@ void luckyBackupWindow::deleteCurrentProfile()
 		message = tr("Are you sure you want to delete profile",
 		"full phrase: 'Are you sure you want to delete profile: <PROFILENAME> ?'")+": <b>" + profileName + "</b> ?";
 
-	int r = QMessageBox::question(this, appName,message,QMessageBox::Yes | 
-					QMessageBox::Default,QMessageBox::No | QMessageBox::Escape);
-	if ( r == QMessageBox::Yes )		//if user answers yes
+	textDialog textdialogQ ("QtQuestion", message, this);
+	textdialogQ.exec();
+
+	if (textdialogQ.getGoOn() > 0)		//if user answers yes
 	{
 		savedProfile = TRUE;	//assume the profile is saved
 		//try to delete the profile
@@ -477,6 +503,228 @@ void luckyBackupWindow::exportProfile()
 	setCurrentProfile(currentProfile);		//reset all currentProfile variables
 }
 
+// duplicateProfile ================================================================================================================================
+// duplicates the current profile
+void luckyBackupWindow::duplicateProfile()
+{
+	InfoData="";
+
+	textDialog textdialog ("RenameProfile", profileName, this);
+	textdialog.exec();
+	if (textdialog.getGoOn() == 0)
+		return;
+
+	if (textdialog.getGoOn() == 2)
+	{
+		InfoData = tr("Failed to duplicate profile","full phrase: 'Failed to duplicate profile <PROFILENAME>'")+
+			" <b>" + profileName + "</b><br><font color=red>"
+			+ "The name you have entered contains only invalid characters" +"</font>";
+		ui.textBrowser_info -> setText(InfoData);	//update the info window
+		return;
+	}
+
+	QString duplicateProfileName = textdialog.getUserInput();
+	QString duplicateProfile = profileDir + duplicateProfileName + ".profile";
+
+	//check if it exists and ask to replace
+	QFile duplicateprofile;
+	duplicateprofile.setFileName(duplicateProfile);
+
+	if (duplicateprofile.exists())			//if the duplicateprofile already exists ask to replace
+	{
+		message = tr("Profile","full phrase: 'Profile <PROFILENAME> already exists'")+" <b>" + duplicateProfileName + "</b> " +
+			tr("already exists","full phrase: 'Profile <PROFILENAME> already exists'") + "<br>" +
+			tr("Would you like to replace it ?");
+		textDialog textdialogQ ("QtQuestion", message, this);
+		textdialogQ.exec();
+
+		if (textdialogQ.getGoOn() > 0)		//if user answers yes
+		{
+			if (!duplicateprofile.remove())	// delete the old profile or display a message if you can't
+			{
+				InfoData = "<font color=red><b>" + tr("ERROR") + "</font></b><br>" +
+					tr("Failed to replace profile",
+					"full phrase: 'Failed to replace profile <PROFILENAME>'")+" <b>" + duplicateProfileName + "</b><br><font color=red>"
+					+ duplicateprofile.errorString() +"</font>";
+				ui.textBrowser_info -> setText(InfoData);	//update the info window
+				return;
+			}
+		}
+		else
+			return;
+	}
+
+	if (!saveProfile(duplicateProfile))	//try to save the new (duplicate) profile
+	{
+		InfoData = "<font color=red><b>" + tr("ERROR") + "</font></b><br>" +
+			tr("Failed to duplicate profile","full phrase: 'Failed to duplicate profile <PROFILENAME> as <FILENAME>'")+
+			" <b>" + profileName + "</b><br>"
+			+tr("as","full phrase: 'Failed to duplicate profile <PROFILENAME> as <FILENAME>'")+
+			" <b>" + duplicateProfileName +"</b><br><font color=red>"
+			+ profile.errorString() +"</font>";
+		ui.textBrowser_info -> setText(InfoData);	//update the info window
+		setCurrentProfile(currentProfile);		//reset all currentProfile variables
+		return;
+	}
+
+	InfoData.append(tr("Profile","full phrase: 'Profile <PROFILENAME> duplicated successfully as <FILENAME>'") + ": <b>" +
+		profileName + "</b><br>...<font color=green>"
+		+ tr("duplicated successfully as","full phrase: 'Profile <PROFILENAME> duplicated successfully as <FILENAME>'") +
+		"</font> <b>" + duplicateProfileName +"</b>");
+	
+	setCurrentProfile(currentProfile);		//reset all currentProfile variables
+	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
+	ui.textBrowser_info -> setText(InfoData);	//update the info window
+	loadData=""; saveData=""; createData="";
+}
+
+// duplicateTask ================================================================================================================================
+// duplicates the current task (creates a new task - same as selected - and opens modify dialog)
+void luckyBackupWindow::duplicateTask()
+{
+	modifyOK = FALSE;
+	modifyConnected = FALSE;
+	newTaskThisIs = TRUE;
+	
+	currentOperation = ui.listWidget_operations -> currentRow();		//current task list row number
+	if (currentOperation < 0)						//if nothing is selected do nothing
+	{
+		InfoData = tr("Please select a task to duplicate first") + " !!";	
+		ui.textBrowser_info -> setText(InfoData);
+		return;
+	}
+	int oldCurrentOperation = currentOperation;
+	
+	TotalOperations = ui.listWidget_operations -> count();		//Get the Operations list size
+	if ( (TotalOperations) >= (maxOperations-1) )			//if the maxOperations limit-1 is reached 
+	{
+		textDialog textdialogW ("QtWarning", 
+					tr("You have reached the maximum limit of supported tasks")+" <br><br>" +
+					tr("You have to remove a task if you wish to add another !!"), this);
+		textdialogW.exec();
+		return;
+	}
+	
+	currentOperation = TotalOperations;
+	
+	//Create a new array item identical to the one just created
+	operation *tempOp = new operation;
+	*tempOp = *Operation[oldCurrentOperation];
+	Operation[currentOperation] = tempOp;	
+
+	// Reset the last execution time/errors & clear its snapshots list
+	QDateTime newTime;	// empty time variable
+	Operation[currentOperation] -> SetLastExecutionTime (newTime);
+	Operation[currentOperation] -> SetLastExecutionErrors (-1);
+	Operation[currentOperation] -> ClearSnapshotsList();
+	
+	//Change the task name and remove any RESTORE connections
+	Operation[currentOperation] -> SetName ((Operation[currentOperation] -> GetName()) + " DUPLICATE");
+	Operation[currentOperation] -> SetConnectRestore("");
+
+	//add a new item in the operations list
+	ui.listWidget_operations -> addItem( Operation[currentOperation] -> GetName() );
+	ui.listWidget_operations -> setCurrentRow(currentOperation);
+	ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
+	TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
+
+	modify();	//open the modify dialog for the new task
+
+	if (modifyOK)
+		savedProfile = FALSE;			//change profile status to "unsaved"
+	else
+	{
+		//remove already created DUPLICATE TASK from operations list
+		ui.listWidget_operations -> takeItem(currentOperation);		//take out the selected item from the list
+		TotalOperations = ui.listWidget_operations -> count();		//TotalOperations takes the new value (old - 1)
+	}
+}
+
+// AlsoCreateRestore ================================================================================================================================
+//create another operation for RESTORE
+void luckyBackupWindow::AlsoCreateRestore()
+{
+	newTaskThisIs = TRUE;
+	int oldCurrentOperation = ui.listWidget_operations -> currentRow();	//current task list row number;
+
+	if (oldCurrentOperation  < 0)						//if nothing is selected do nothing
+	{
+		InfoData = tr("Please select a task first") + " !!";	
+		ui.textBrowser_info -> setText(InfoData);
+		return;
+	}
+	
+	TotalOperations = ui.listWidget_operations -> count();			//Get the Operations list size
+	if ( (TotalOperations) >= (maxOperations-1) )			//if the maxOperations limit-1 is reached 
+	{
+		textDialog textdialogW ("QtWarning", 
+					tr("You have reached the maximum limit of supported tasks")+" <br><br>" +
+					tr("You have to remove a task if you wish to add another !!"), this);
+		textdialogW.exec();
+		return;
+	}
+	
+	currentOperation = TotalOperations;
+	
+	//Create a new array item identical to the one just created
+	operation *tempOp = new operation;
+	*tempOp = *Operation[oldCurrentOperation];
+	Operation[currentOperation] = tempOp;	
+	
+	// Reset the last execution time/errors & clear its snapshots list
+	QDateTime newTime;	// empty time variable
+	Operation[currentOperation] -> SetLastExecutionTime (newTime);
+	Operation[currentOperation] -> SetLastExecutionErrors (-1);
+	Operation[currentOperation] -> ClearSnapshotsList();
+
+	//Change its name, source, destination, update checkbox, Remote Host radiobuttons
+	Operation[currentOperation] -> SetName ("RESTORE - " + (Operation[currentOperation] -> GetName()));
+	Operation[currentOperation] -> SetOptionsUpdate(FALSE);
+	Operation[currentOperation] -> SetRemoteDestination(Operation[oldCurrentOperation]-> GetRemoteSource());
+	Operation[currentOperation] -> SetRemoteSource(Operation[oldCurrentOperation]-> GetRemoteDestination());
+	QString sourceDir	= Operation[oldCurrentOperation] -> GetDestination();
+	QString destDir		= Operation[oldCurrentOperation] -> GetSource();
+
+	if (Operation[currentOperation] -> GetTypeDirName())
+	{
+		sourceDir.append(destDir.right(destDir.size() - destDir.lastIndexOf("/") - 1));
+		destDir.chop(destDir.size() - destDir.lastIndexOf("/") - 1);
+	}
+
+	Operation[currentOperation] -> SetSource (sourceDir);
+	Operation[currentOperation] -> SetDestination (destDir);
+
+	//add a new item in the operations list
+	ui.listWidget_operations -> addItem( Operation[currentOperation] -> GetName() );
+	ui.listWidget_operations -> setCurrentRow(currentOperation);
+	ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
+	TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
+
+	textDialog textdialogW ("QtWarning", 
+		tr("You have asked for a RESTORE task to be created","'create restore' message line 1/4")+"<br><br>"+
+		tr("Please have a good look at the following task properties dialog","'create restore' message line 2/4")+" <br>"+
+		tr("and change anything you wish before proceeding","'create restore' message line 3/4")+" <br><br>"+
+		tr("Especially check 'Task name', 'source', 'destination' & 'skip newer destination files' checkbox (advanced)","'create restore' message line 4/4")+"<br>",
+				this);
+	textdialogW.exec();
+
+	modifyConnected = TRUE;
+	modify();	//open the modify dialog for the new operation to make sure everything is ok
+
+	if (modifyOK)		//connect the operation with its RESTORE duplicate
+	{
+		Operation[currentOperation] -> SetConnectRestore(Operation[oldCurrentOperation] -> GetName());	
+		Operation[oldCurrentOperation] -> SetConnectRestore(Operation[currentOperation] -> GetName());
+		savedProfile = FALSE;			//change profile status to "unsaved"
+	}
+	else
+	{
+		//remove already created RESTORE operation from operations list
+		ui.listWidget_operations -> takeItem(currentOperation);		//take out the selected item from the list
+		TotalOperations = ui.listWidget_operations -> count();		//TotalOperations takes the new value (old - 1)
+	}
+}
+
 // importProfile ================================================================================================================================
 // imports a profile to the profile directory
 void luckyBackupWindow::importProfile()
@@ -553,6 +801,31 @@ void luckyBackupWindow::setLanguage(QAction *action)
 	retranslateUi();
 }
 
+// hideShowInfoWindow ===============================================================================================================================
+// Shows / hides the information window
+void luckyBackupWindow::hideShowInfoWindow()
+{
+	IsVisibleInfoWindow = !(ui.pushButton_InfoCollapse -> isChecked());
+	if (IsVisibleInfoWindow)
+	{
+		ui.pushButton_InfoCollapse -> setToolTip(tr("Hide information window","hide/show information window button tooltip"));
+		ui.pushButton_InfoCollapse -> setIcon(QIcon(":/luckyPrefix/collapse.png"));
+		if (guiModeNormal)
+			ui.textBrowser_info -> setVisible (TRUE);
+		else
+			ui.nowDoing	-> setVisible (TRUE);
+	}
+	else
+	{
+		ui.pushButton_InfoCollapse -> setToolTip(tr("Show information window","hide/show information window button tooltip"));
+		ui.pushButton_InfoCollapse -> setIcon(QIcon(":/luckyPrefix/collapseUP.png"));
+		if (guiModeNormal)
+			ui.textBrowser_info -> setVisible (FALSE);
+		else
+			ui.nowDoing	-> setVisible (FALSE);
+	}
+}
+
 // help =============================================================================================================================================
 // Shows the "help" information window
 void luckyBackupWindow::help()
@@ -564,8 +837,19 @@ void luckyBackupWindow::help()
 		ui.textBrowser_info -> setText(InfoData);	//update the info window
 		return;
 	}
-	helpBrowser helpbrowser (helpURL);
-	helpbrowser.exec();
+	
+	//the following was used when helpBrowser was a modal dialog - can take it out if you wish
+	//	helpBrowser helpbrowser (helpURL);
+	//	helpbrowser.exec();
+
+	if (!helpbrowser)
+		helpbrowser = new helpBrowser (helpURL);
+
+	if (helpbrowser->isHidden())
+		helpbrowser->show();
+	
+	helpbrowser->raise();
+	helpbrowser->activateWindow();
 }
 
 // about ============================================================================================================================================
@@ -588,10 +872,10 @@ void luckyBackupWindow::add()
 
 	if ( (TotalOperations) >= (maxOperations-1) )					//if the maxOperations limit-1 is reached 
 	{
-		QMessageBox::warning(this, appName,
-				tr("You have reached the maximum limit of supported tasks")+" <br><br>" +
-				tr("You have to remove a task if you wish to add another !!"),
-				QMessageBox::Ok | QMessageBox::Default);
+		textDialog textdialogW ("QtWarning", 
+					tr("You have reached the maximum limit of supported tasks")+" <br><br>" +
+					tr("You have to remove a task if you wish to add another !!"), this);
+		textdialogW.exec();
 		return;
 	}
 
@@ -609,10 +893,6 @@ void luckyBackupWindow::add()
 		TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
 		savedProfile = FALSE;			//change profile status to "unsaved"
 	}
-
-	//If also create Restore operation is checked - Create a new operation and modify it
-	if ( (modifyOK) && (Operation[currentOperation] -> GetAlsoCreateRestore()) && (!Operation[currentOperation] -> GetTypeSync()) )
-		AlsoCreateRestore();
 }
 
 //  modify ==========================================================================================================================================
@@ -633,20 +913,14 @@ void luckyBackupWindow::modify()
 	if ( (tempConnect != "") && (!modifyConnected) )	//the operations is connected and is a not new RESTORE operation
 		modifyConnected = TRUE;
 	int connectPosition=0;
-	if (tempConnect != "")	//if this op is already connected with another op, pop up a message & hold the connection's position
+	if (tempConnect != "")	//if this op is already connected with another op, (pop up a message & )hold the connection's position
 	{
-		count=0; while (count<TotalOperations){					//get the connected operation position at connectPosition
+		count=0;
+		while (count<TotalOperations)
+		{					//get the connected operation position at connectPosition
 			if  (Operation[count]->GetName()==tempConnect) connectPosition=count;
-			count++;}
-
-		int r=QMessageBox::warning(this, appName,tr("You have asked to modify a task that is connected to :",
-			"full phrase: 'You have asked to modify a task that is connected to :<TASKNAME> which is not going to be modified'")+"<br>"+
-			tempConnect + "<br>"+tr("which is not going to be modified",
-			"full phrase: 'You have asked to modify a task that is connected to :<TASKNAME> which is not going to be modified'")+
-			"<br><br>"+tr("Press 'Yes' to proceed"),
-			QMessageBox::Yes | QMessageBox::Default,
-			QMessageBox::Cancel | QMessageBox::Escape);
-		if ( r == QMessageBox::Cancel ) return;
+			count++;
+		}
 	}
 
 	//open the modify dialog and modify "Operation array" item at position currentOperation
@@ -662,15 +936,11 @@ void luckyBackupWindow::modify()
 		ui.listWidget_operations -> setCurrentRow(currentOperation);		//highlight this row
 		ui.listWidget_operations -> currentItem() -> setCheckState(isIncluded); //set the include checkbox as it was
 		Operation[currentOperation] -> SetConnectRestore(tempConnect);		//set the connection to what it was
-		if (tempConnect != "") Operation[connectPosition]->SetConnectRestore(Operation[currentOperation] -> GetName());
+		if (tempConnect != "")
+			Operation[connectPosition]->SetConnectRestore(Operation[currentOperation] -> GetName());
 		checkCurrentItem();
 		savedProfile = FALSE;			//change profile status to "unsaved"
 	}
-
-	//If also create Restore operation is checked - Create a new operation and modify it
-	if ( (modifyOK) && (!modifyConnected) && (Operation[currentOperation] -> GetAlsoCreateRestore()) 
-		&& (!Operation[currentOperation] -> GetTypeSync()) )
-		AlsoCreateRestore();
 }
 
 // remove ===========================================================================================================================================
@@ -687,17 +957,16 @@ void luckyBackupWindow::remove()
 
 	QString tempConnect = Operation[currentOperation] -> GetConnectRestore();
 
-	int r = QMessageBox::warning(this, appName,tr("Are you sure you want to remove the following task ??")+" <br>" +
- 				(ui.listWidget_operations -> currentItem()) -> text(),
-				QMessageBox::Yes | QMessageBox::Default,
-				QMessageBox::Cancel | QMessageBox::Escape);
-	int r2=0;
-	if ( r == QMessageBox::Yes )
+	textDialog textdialogQ ("QtQuestion", tr("Are you sure you want to remove the following task ??")+" <br>" +
+ 				(ui.listWidget_operations -> currentItem()) -> text(), this);
+	textdialogQ.exec();
+
+	if (textdialogQ.getGoOn() > 0)		//if user answers yes
 	{
+		textDialog textdialogQ2 ("QtQuestion", tr("Would you like to also remove:")+" <br>" + tempConnect+"<br>??", this);
 		if (tempConnect != "")	//if this op is already connected with another op ask to remove that too
-			r2 = QMessageBox::warning(this, appName,tr("Would you like to also remove:")+" <br>" + tempConnect+"<br>??",
-				QMessageBox::Yes | QMessageBox::Default,
-				QMessageBox::Cancel | QMessageBox::Escape);
+			textdialogQ2.exec();
+		
 		//remove current operation
 		ui.listWidget_operations -> takeItem(currentOperation);		//take out the selected item from the list
 		TotalOperations = ui.listWidget_operations -> count();		//TotalOperations takes the new value (old - 1)
@@ -713,7 +982,7 @@ void luckyBackupWindow::remove()
 			while (currentOperation < TotalOperations)
 			{	if (Operation[currentOperation]->GetName()==tempConnect)
 				{
-					if (r2==QMessageBox::Yes)		//remove current (conected) operation
+					if (textdialogQ2.getGoOn() > 0)		//remove current (conected) operation
 					{
 						ui.listWidget_operations -> takeItem(currentOperation);	
 						TotalOperations = ui.listWidget_operations -> count();
@@ -748,6 +1017,10 @@ void luckyBackupWindow::manage()
 	
 	manageDialog managedialog;
 	managedialog.exec();
+	
+	checkCurrentItem();	//refresh the selected task
+	saveCurrentProfile();	// save the profile if any snapshots have been deleted
+//	refreshList(); //refresh the listWidget_operations
 }
 
 // moveUp ===========================================================================================================================================
@@ -873,11 +1146,29 @@ void luckyBackupWindow::checkCurrentItem()
 	InfoData="";
 	CheckedData = "";
 	currentOperation = ui.listWidget_operations -> currentRow();
-
+	
+	if (currentOperation <0)	// to avoid segfault when nothing selected
+		return;
+	
 	//first set  variables source & dest
 	QString source, dest;
 	source = Operation[currentOperation] -> GetSource();
 	dest = Operation[currentOperation] -> GetDestination();
+	
+	if (Operation[currentOperation] -> GetTypeSync())	//if the operation is of type "sync dirs'
+	{
+		ui.action_TaskCreateRestore -> setEnabled(FALSE);	//grey out the "create restore task" from menu
+		ui.action_TaskManageBackup -> setText(tr("Manage Task","This is a top 'Task' menu action"));
+		ui.action_TaskManageBackup -> setToolTip(tr("display information regarding highlighted task",
+						    "This is a top 'Task' menu action tooltip"));
+	}
+	else
+	{
+		ui.action_TaskCreateRestore -> setEnabled(TRUE);
+		ui.action_TaskManageBackup -> setText(tr("Manage &Backup","This is a top 'Task' menu action"));
+		ui.action_TaskManageBackup -> setToolTip(tr("display - restore - delete existing backups of highlighted task",
+						    "This is a top 'Task' menu action tooltip"));
+	}
 
 	if (ui.listWidget_operations -> currentItem() -> checkState() == Qt::Unchecked)	//if the operation is " NOT included" do not check it
 	{
