@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 26 Nov 2009
+ last modified 		: 11 May 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -44,7 +44,7 @@ class luckyBackupWindow : public QMainWindow
 	
 	public:
 		luckyBackupWindow (QMainWindow *parent = 0);
-
+		
 		// general variables
 		bool taskClicked;	//these 2 bool vars help to determine when a checkbox state is changed for SLOT taskStateChanged
 		bool taskChanged;
@@ -68,6 +68,7 @@ class luckyBackupWindow : public QMainWindow
 		void renameCurrentProfile();	//SLOT: rename the current profile
 		void exportProfile();		//SLOT to export a profile
 		void importProfile();		//SLOT to import a profile
+		void duplicateProfile();	//SLOT to duplicate a profile		
 
 		void exitApp();		//SLOT: check if a profile is saved and exit application
 
@@ -81,16 +82,21 @@ class luckyBackupWindow : public QMainWindow
 		void taskStateChanged();	//SLOT: Sets the profile state to unsaved if a task checkbox is changed
 		void refreshList();	//SLOT: Refresh the operations list when refresh button pressed
 		void start();		//SLOT: Open start operations dialog when Button clicked()
-		void modify();		//SLOT: Mosify an existing operation
-		void add();		//SLOT: Add a new operation
-		void remove();		//SLOT: remove highlighted operation
-		void manage();		//SLOT: Manage existing backups of an existing operation
+		void modify();		//SLOT: Mosify an existing task
+		void add();		//SLOT: Add a new task
+		void remove();		//SLOT: remove highlighted task
+		void manage();		//SLOT: Manage existing backups of an existing task
+		void AlsoCreateRestore();//SLOT: Create another operation for RESTORE
+		void duplicateTask();		//SLOT to duplicate a task
 		void moveUp();		//SLOT: move  highlighted operation one position up
 		void moveDown();	//SLOT: move  highlighted operation one position down
 		void schedule();	//SLOT: Open schedule dialog when Button clicked()
+		
+		void hideShowInfoWindow();	// SLOT to hide or show the info window
 
 		//execute.cpp SLOTS
-		void buttonPressed();		//SLOT when buutton pressed( see also notYet)
+		void abortPressed();		//SLOT when button pressed( see also notYet)
+		void donePressed();		//SLOT when done button pressed
 		void appendRsyncOutput();	//Display o/p to textbrowser & update logfile
 		void procFinished();		//SLOT executed when syncProcess is finshed (will start a new syncProcess if any left)
 		
@@ -103,23 +109,27 @@ class luckyBackupWindow : public QMainWindow
 
 	private:
 		Ui::luckyBackupWindow ui;
+		
 		QSystemTrayIcon *LBtray;	//this is luckybackup's tray icon
 		QMenu *languageMenu;
 		QMenu *settingsMenu;
+		QMenu *toolbarsMenu;
 		QActionGroup *languageGroup;
+		QActionGroup *toolbarsGroup;
 		QMenu *helpMenu;
 		QAction *action;
 		QAction *actionHelp;
 		QAction *actionAbout;
 		QToolBar *profileToolbar;
 		QToolBar *profileComboToolbar;
+		QToolBar *profileStartToolbar;
 		QAction *visibleProfileToolbar;
 		QAction *visibleProfileComboToolbar;
+		QAction *visibleProfileStartToolbar;
 		QAction *actionLockToolbars;
 		QAction *actionVisibleToolbarText;
 		
 		//The following functions are inside functions.cpp~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-		void AlsoCreateRestore();		//function to create another operation for RESTORE
 		void setCurrentProfile(QString);	//function to check if a profile is valid and load it by calling loadProfile
 		bool loadCurrentProfile();		//function to  load an existing profile
 		bool saveCurrentProfile();		//function to save a profile 
@@ -145,7 +155,9 @@ class luckyBackupWindow : public QMainWindow
 		bool AreToolbarsLocked;			// holds the lock state of the toolbars
 		bool IsVisibleProfileComboToolbar;	// holds the visible state of the profile combo toolbar
 		bool IsVisibleProfileToolbar;		// holds the visible state of the profile toolbar
+		bool IsVisibleProfileStartToolbar;	// holds the visible state of the profile start toolbar
 		bool IsVisibleToolbarText;		// holds the visible state of the toolbar text
+		bool IsVisibleInfoWindow;		// holds the visible state of the info window
 
 		//inside execute.cpp-----------------------------------------------------
 		void executeNOW();	//start the execution of commands (rsync & others)
@@ -155,6 +167,10 @@ class luckyBackupWindow : public QMainWindow
 		int errorCount;		//used for next/previous error button
 		bool firstScroll;	//used for next/previous error button
 		bool NOWexecuting;	//becomes true if a profile execution is running
+		bool guiModeNormal;	//becomes true when the gui is in normnal mode
+		bool ABORTpressed;	//becomes true if the abort button is pressed
+		void finishUp();	// finish up some stuff when all tasks finish either normally or aborted
+		
 		
 		//Progress bar variables
 		int progress_total;	//Maximum value of progress
@@ -174,11 +190,13 @@ class luckyBackupWindow : public QMainWindow
 		QString dirB;			//holds the second dir to be synced
 		
 		bool calculating;		//these 3 bools are used to diplay progress of rsync at the info window
-		bool transfering;
+		bool transferring;
 		bool deleting;
 		
 		bool ExecuteBefore;		//becomes true if a before command is to be executed, not rsync !!
 		bool ExecuteAfter;		//becomes true if a after command is to be executed, not rsync !!
+		bool ExecuteBeforeExitedError;	// becomes true if a before command exits with an error
+		bool DestCreateFail;		// // This will become TRUE if destination does not exist and cannot be created
 		int currentBefore;		//count variable for commands to be executed before task
 		int currentAfter;		//count variable for commands to be executed before task
 		void executeBeforeTask();	//function to start execution of pre-task commands
