@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: Loukas Avgeriou 
- last modified 		: 20 Oct 2009
+ last modified 		: 05 May 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -32,59 +32,48 @@
 #define MANAGE_H
 
 #include "ui_manage.h"
-#include <QCheckBox>
-#include <QFileSystemModel>
-#include <QTreeWidgetItem>
-//==============================================================================================================
-//Declaration of manageDialog class (this is the dialog that manmages existing backups of a task)
 
-namespace BrowseFolder { class modelo; }
+//==============================================================================================================
+//Declaration of manageDialog class (this is the dialog that manages existing backups of a task)
 
 class manageDialog : public QDialog
 {
 	Q_OBJECT
 	
-	friend class BrowseFolder::modelo;
-	
 	public:
 		manageDialog (QDialog *parent=0);
-		
-		QStringList dirs() const { return m_dirs; }
 
 	private slots:
-		void cancel();
+		void cancel();		// close the manage dialog
 		void logView();		// view the log file
-
+		void restoreBackup();	// launch the restore wizard
+		void deleteBackup();	// launch the delete wizard
+		void fixGui();		// makes some changes to the gui according to various stuff
+		void SnapshotsListSelected();	//Triggered when selection changes
+		void calculateDifferences();	// calculate differences between source and snapshot
+		void hideSourceStuff();		// hide -show source stuff
+		
 	private:
 		Ui::manageDialog uiG;
-		BrowseFolder::modelo *m_model;
-		QStringList m_dirs;
+		
+		QString source;
+		QString sourceLast;
+		QString dest;
+		QString time;
+		QString CurrentSnapshotString;	// This is the current snapshot in YYYYmmddHHmmss format
+		QString CurrentSnapshotDirectory ;	// This is the full path of the current snapshot directory
+		int CurrentSnapshotNo;		// This is the current snapshot number (order in list). Becomes 0,1,2 .... currentSnaps
+		int currentSnaps;		// this is the current number of already created snapshots
+		int count;			//simple count variable
+		bool syncTYPE;			// This will become true if it is a sync task
+		bool sourceVisible;		// Helps to hide/show source stuff
+		QStringList calculatedDifferences;// Text of calculated deifferences is stores here for each snapshot
+		QList<bool> snapCalculated;	// becomes true if differences have been calculated for a snapshot
+		
+		void updateSnapshots();
+		QString readDirEntries(QString);	// Read all entries of a directory except stuff we do not want to
 }; 
 
-namespace BrowseFolder
-{
-	class modelo : public QFileSystemModel
-	{
-		public:
-		modelo();
-
-		virtual Qt::ItemFlags flags( const QModelIndex &index ) const;
-		QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
-		bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );
-
-		void setDirectories( QStringList &dirs );
-		QStringList directories() const;
-
-		virtual int columnCount( const QModelIndex& ) const { return 4; }
-
-		private:
-		bool ancestorChecked( const QString &path ) const;
-		bool descendantChecked( const QString &path ) const;
-		QSet<QString> m_checked;
-	};
-
-} // end namespace BrowseFolder
-
 #endif
 
 // end of manage.h ---------------------------------------------------------------------------
