@@ -4,7 +4,7 @@ Display a dialog. Adds a new or modifies an existing operation
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Display a dialog. Adds a new or modifies an existing operation
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 12 Dec 2009
+ last modified 		: 11 Jun 2010
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -45,12 +45,20 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	this -> resize(stdWindowWidth,minWindowHeight);
 	ArrayPosition = ItemNo;
 	validation = FALSE;
+	
+	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+	// Disable/hide stuff that is under testing/developement
+//	uiM.spinBox_snapshotsKeep 	-> setEnabled(FALSE);
+//	uiM.label_snapshotsKeep 	-> setEnabled(FALSE);
+	uiM.toolBox_options 		->setItemEnabled (0,FALSE);	// different backend
+	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 	//connections ----------------------------------------------------------------------------------------------------
 	connect(uiM.pushButton_advanced, SIGNAL( toggled(bool) ), this, SLOT(advancedPressed(bool) ) );	//advanced pushButton
 	connect(uiM.pushButton_cancel, SIGNAL( pressed() ), this, SLOT(cancelPressed() ) );		//cancel pushButton
 	connect(uiM.pushButton_okay, SIGNAL( pressed() ), this, SLOT(okayPressed() ) );			//okay pushButton
 	connect(uiM.pushButton_command, SIGNAL( pressed() ), this, SLOT(commandPressed() ) );		//show command pushButton
+	connect(uiM.comboBox_Type, SIGNAL( currentIndexChanged(int) ), this, SLOT(TaskTypeChanged(int) ) ); //Actions when task type combo changes
 
 	//Connect all add list items buttons with the addListItem SLOT
 	//Map all the pushButton signals and transmit a different integer depending on the pushbutton
@@ -97,6 +105,10 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	connect (uiM.toolButton_executeBeforeBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	signalMapper ->	setMapping ( uiM.toolButton_executeAfterBrowse, 7 );
 	connect (uiM.toolButton_executeAfterBrowse, SIGNAL (clicked() ), signalMapper , SLOT (map()));
+	signalMapper ->	setMapping ( uiM.toolButton_includeFile, 8 );
+	connect (uiM.toolButton_includeFile, SIGNAL (clicked() ), signalMapper , SLOT (map()));
+	signalMapper ->	setMapping ( uiM.toolButton_excludeFile, 9 );
+	connect (uiM.toolButton_excludeFile, SIGNAL (clicked() ), signalMapper , SLOT (map()));
 	connect(signalMapper, SIGNAL(mapped( const int)), this, SLOT( browse( const int) )  );
 
 	//Connect all pattern toolButtons with the getPattern SLOT
@@ -108,8 +120,6 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	connect (uiM.toolButton_includeAddPattern, SIGNAL (clicked() ), signalMapper4 , SLOT (map()));
 	connect(signalMapper4, SIGNAL(mapped( const int)), this, SLOT( getPattern( const int) )  );
 	
-	if (modifyConnected)			//if this operation is connected to another
-		uiM.checkBox_alsoCreateRestore -> setVisible(FALSE);
 	if (ArrayPosition < TotalOperations)	//if modify is pressed fill the fields first with existing operation data
 		fillModifyWindow(Operation[ArrayPosition]);
 	
@@ -125,6 +135,8 @@ modifyDialog::modifyDialog (int ItemNo, QDialog *parent) : QDialog (parent)
 	uiM.lineEdit_sshPassword -> setCompleter(completer);
 	uiM.lineEdit_executeBeforeAdd -> setCompleter(completer);
 	uiM.lineEdit_executeAfterAdd -> setCompleter(completer);
+	uiM.lineEdit_excludeFile -> setCompleter(completer);
+	uiM.lineEdit_includeFile -> setCompleter(completer);
 }
 //===================================================================================================================================================
 //------------------------------------------------------------------SLOTS----------------------------------------------------------------------------
@@ -171,35 +183,53 @@ void modifyDialog::browse(const int type)
 	switch (type)
 	{
 		//source browse button
-		case 0:	newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select source directory"),uiM.lineEdit_source -> text());
+		case 0:	newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select source directory",
+			"file selection dialog title"),uiM.lineEdit_source -> text());
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_source 	-> setText(newLineEdit);
 			break;
 		//destination browse button
-		case 1: newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select destination directory"),uiM.lineEdit_destination -> text());
+		case 1: newLineEdit = QFileDialog::getExistingDirectory (this, tr("Select destination directory",
+			"file selection dialog title"),uiM.lineEdit_destination -> text());
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_destination -> setText(newLineEdit);
 			break;
 		//rsync password file browse button
-		case 4:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select rsync password file"), myHome);
+		case 4:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select rsync password file",
+			"file selection dialog title"), myHome);
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_rsyncPassword -> setText(newLineEdit);
 			break;
 		//ssh password file browse button
-		case 5:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile"), myHome + "/.ssh");
+		case 5:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select ssh keyfile",
+			"file selection dialog title"), myHome + "/.ssh");
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_sshPassword -> setText(newLineEdit);
 			break;
 		//execute before browse button
-		case 6:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select command to be executed"),"/");
+		case 6:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select command to be executed",
+			"file selection dialog title"),"/");
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_executeBeforeAdd -> setText(newLineEdit);
 			break;
 		//execute after browse button
-		case 7:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select command to be executed"),"/");
+		case 7:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select command to be executed",
+			"file selection dialog title"),"/");
 			if (newLineEdit != "")	//if something is selected indeed
 				uiM.lineEdit_executeAfterAdd -> setText(newLineEdit);
 			break;
+		//include from file browse button
+		case 8:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file to read include patterns",
+			"file selection dialog title"),myHome);
+			if (newLineEdit != "")	//if something is selected indeed
+				uiM.lineEdit_includeFile -> setText(newLineEdit);
+			break;
+		//exclude from file browse button
+		case 9:	newLineEdit = QFileDialog::getOpenFileName (this, tr("Select file to read exclude patterns",
+			"file selection dialog title"),myHome);
+			if (newLineEdit != "")	//if something is selected indeed
+				uiM.lineEdit_excludeFile -> setText(newLineEdit);
+			break;
 	}
 
 }
@@ -209,12 +239,13 @@ void modifyDialog::getPattern(const int type)
 {	
 	if (uiM.lineEdit_source -> text() == "")	//if the source isn't defined yet
 	{
-		QMessageBox::warning(this, appName,
-			tr("Please define the source before launching the pattern editor")+" !!",
-			QMessageBox::Ok | QMessageBox::Default);
+		textDialog textdialogW ("QtWarning", tr("Please define the source before launching the pattern editor","message box, message")+" !!", this);
+		textdialogW.exec();
 		return;
 	}
 
+	modifyTrailing(); // first modify the trailing of the source & destination directories
+	
 	QString NewPattern = "";
 	
 	patternEditor patterneditor(uiM.lineEdit_source -> text(), this);
@@ -240,12 +271,16 @@ void modifyDialog::okayPressed()
 {
 	modifyOK = TRUE;
 	message = "";
+	
+	// Strip off invalid characters from task name
+	uiM.lineEdit_name -> setText(stripInvalidCharacters(uiM.lineEdit_name -> text()));
 
 	//if name or source or destination is missing do not proceed -----------------------------------------------------------
 	if ( (uiM.lineEdit_name -> text() == "") || (uiM.lineEdit_destination -> text() == "") || (uiM.lineEdit_source -> text() == "")  )
 	{
 		modifyOK = FALSE;
-		message.append("<b>"+tr("ERROR")+":</b> "+tr("Please specify the following before proceeding:"));
+		message.append("<b>"+tr("ERROR","message box message")+":</b> "+
+					tr("Please specify the following before proceeding:","message box, message"));
 		if (uiM.lineEdit_name -> text() == "")
 			message.append("<br>"+tr("Task name"));
 		if (uiM.lineEdit_destination -> text() == "")
@@ -259,9 +294,10 @@ void modifyDialog::okayPressed()
 	if ((uiM.lineEdit_source -> text() == "/") && (uiM.comboBox_Type -> currentIndex()==1))
 	{
 		modifyOK = FALSE;
-		message.append("<b>"+tr("ERROR")+":</b> "+tr("You have declared the '/' (root) directory as source and 'backup dir by name' as task type'")+"<br>"+
-				tr("That is not allowed because '/' does not have an actual name")+" !!<br>"
-				"..."+tr("Please specify a different task type")+"<br><br>");
+		message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+		tr("You have declared the '/' (root) directory as source and 'backup dir by name' as task type'","message box message - line1")+"<br>"+
+				tr("That is not allowed because '/' does not have an actual name","message box message - line2")+" !!<br>"
+				"..."+tr("Please specify a different task type","message box message - line3")+"<br><br>");
 	}
 
 	//check if the operation name already exists to proceed --------------------------------------------------------------------
@@ -271,8 +307,9 @@ void modifyDialog::okayPressed()
 		if ( ((uiM.lineEdit_name -> text()) == (Operation[count] -> GetName()) ) && (count != ArrayPosition) )
 		{
 			modifyOK = FALSE;
-			message.append("<b>"+tr("ERROR")+":</b> "+tr("The name of the task you requested already exists")+" !!<br>"
-					"..."+tr("Please specify a different name before proceeding")+"<br><br>");
+			message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+			tr("The name of the task you requested already exists","message box message - line1")+" !!<br>"
+					"..."+tr("Please specify a different name before proceeding","message box message - line2")+"<br><br>");
 			break;
 		}
 		count++;
@@ -288,36 +325,42 @@ void modifyDialog::okayPressed()
 		|| ( (uiM.lineEdit_source -> text() + "/") == (uiM.lineEdit_destination -> text()) )	) && (!uiM.groupBox_remote -> isChecked()) )
 		{
 			modifyOK = FALSE;
-			message.append("<b>"+tr("ERROR")+":</b> "+tr("The source you have declared is identical to the destination")+" !!<br>"
-					"..."+tr("Please modify at least one of them")+"<br><br>");
+			message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+			tr("The source you have declared is identical to the destination","message box message - line1")+" !!<br>"
+					"..."+tr("Please modify at least one of them","message box message - line2")+"<br><br>");
 		}
 		else	//check if the destination is part of the source directory structure ------------------------------------------------
 		if ( 	((uiM.lineEdit_destination -> text()).contains(uiM.lineEdit_source -> text(), Qt::CaseSensitive) )
 		||	((uiM.lineEdit_destination -> text()).contains(uiM.lineEdit_source -> text() + "/", Qt::CaseSensitive))	)
-				message.prepend("<b>"+tr("WARNING")+":</b> "+tr("You have declared a destination that is part of the source directory structure")+"<br>"
-					"<b>"+tr("Do not forget</b> to define a directory at the 'exclude' groupbox that will contain the destination")+"<br><br>");
+				message.prepend("<b>"+tr("WARNING","message box message - line1")+":</b> "+
+					tr("You have declared a destination that is part of the source directory structure",
+					   "message box message - line1")+"<br>"
+					+tr("<b>Do not forget</b> to define a directory at the 'exclude' groupbox that will contain the destination",
+					"message box message - line2. Please leave tag <b>,</b> intact and surrounding 'do not forget' translated")+"<br><br>");
 	}
 
 	//"recursive" has to be checked for --delete-after to operate -------------------------------------------------------------
 	if ( (uiM.checkBox_deleteAfter -> isChecked()) && !(uiM.checkBox_recurse -> isChecked()) )
 	{
 		modifyOK = FALSE;
-		message.append("<b>"+tr("ERROR")+":</b> "+tr("You have checked the 'delete files on the destination' option <br>"
-				"without having checked 'Recurse into directories' which is required")+"<br><br>");
+		message.append("<b>"+tr("ERROR","message box message - line1")+":</b> "+
+		tr("You have checked the 'delete files on the destination' option","message box message - line2") + "<br>" +
+				tr("without having checked 'Recurse into directories' which is required","message box message - line3")+"<br><br>");
 	}
 
 	//check if "remote" is checked and no hostname is declared -----------------------------------------------------------------
 	if ( (uiM.groupBox_remote -> isChecked()) && (uiM.lineEdit_remoteHost -> text() == "") )
 	{
 		modifyOK = FALSE;
-		message.append("<b>"+tr("ERROR")+":</b>"+tr("'Remote Host' is checked, but no remote host name is declared")+"<br>"+
-				tr("Please specify a remote host name")+"<br>"+
-				tr("Otherwise uncheck 'Remote Host' to operate locally")+"<br><br>");
+		message.append("<b>"+tr("ERROR","message box message - line1")+":</b>"+
+				tr("'Remote Host' is checked, but no remote host name is declared","message box message - line2")+"<br>"+
+				tr("Please specify a remote host name","message box message - line3")+"<br>"+
+				tr("Otherwise uncheck 'Remote Host' to operate locally","message box message - line4")+"<br><br>");
 	}
 
 	bool tempCloneWarning = TRUE;
 	//use this cause the next command will set CloneWARNING to TRUE by creating a new operation
-	// only perform this if "modify is pressed, not "new" task
+	// only perform this if "modify is pressed, not "new/duplicate/restore" task
 	if (!newTaskThisIs)
 		tempCloneWarning = Operation[ArrayPosition] -> GetCloneWARNING ();
 	
@@ -346,7 +389,10 @@ void modifyDialog::okayPressed()
 				close();	//emmit a QcloseEvent
 		}
 		else			//display a warning message
-			QMessageBox::warning(this, appName+" - "+tr("WARNING")+" !!", message, QMessageBox::Ok | QMessageBox::Default);
+		{
+			textDialog textdialogW ("QtWarning", message, this);
+			textdialogW.exec();
+		}
 	}
 }
 
@@ -373,14 +419,15 @@ void modifyDialog::commandPressed()
 	}
 	
 	if (modifyOK)
-		message.prepend(tr("All declared fields of the task properties window seem to be ok")+"<br><br>");
+		message.prepend(tr("All declared fields of the task properties window seem to be ok","message box message first line")+"<br><br>");
 	else
-		message.prepend("<b>"+tr("Errors have been found")+"...</b><br><br>");
+		message.prepend("<b>"+tr("Errors have been found","message box message first line")+"...</b><br><br>");
 
-	message.append("<b>"+tr("command to be executed")+":</b><br>");
-	QMessageBox::information(this, appName, message + "<font color=red>rsync </font><font color=blue>" + tempArgs +
-		"</font><br><font color=magenta>"+ source + "</font><br><font color=magenta>" + dest + "</font><br>",
-		 QMessageBox::Ok | QMessageBox::Default); 
+	message.append("<b>"+tr("command to be executed","full phrase: command to be executed: <COMMAND>")+":</b><br>");
+	
+	textDialog textdialog ("ValidateDialog", message + "<font color=red>rsync </font><font color=blue>" + tempArgs +
+		"</font><br><font color=magenta>"+ source + " </font><br><font color=magenta>" + dest + "</font><br>", this);
+	textdialog.exec();
 
 	validation = FALSE;
 	//==========================================================================================================================
@@ -410,10 +457,10 @@ void modifyDialog::addListItem(const int type)
 					uiM.lineEdit_excludeAdd -> clear();
 				}
 				else
-					QMessageBox::warning(this, appName,
-						tr("You have already added this exclude item")+" !!<br>" ,
-						QMessageBox::Ok | QMessageBox::Default);
-		
+				{
+					textDialog textdialogW ("QtWarning", tr("You have already added this exclude item","message box message")+" !!<br>" , this);
+					textdialogW.exec();
+				}
 			}
 			break;
 		//include list add button
@@ -432,10 +479,10 @@ void modifyDialog::addListItem(const int type)
 					uiM.lineEdit_includeAdd -> clear();
 				}
 				else
-					QMessageBox::warning(this, appName,
-						tr("You have already added this include item")+" !!<br>" ,
-						QMessageBox::Ok | QMessageBox::Default);
-		
+				{
+					textDialog textdialogW ("QtWarning", tr("You have already added this include item","message box message")+" !!<br>" , this);
+					textdialogW.exec();
+				}
 			}
 			break;
 		//options list add button
@@ -453,10 +500,12 @@ void modifyDialog::addListItem(const int type)
 					uiM.listWidget_options -> addItem(text);
 					uiM.lineEdit_optionsAdd -> clear();
 				}
+
 				else
-					QMessageBox::warning(this, appName,
-						tr("You have already added this option")+" !!<br>",
-						QMessageBox::Ok | QMessageBox::Default);
+				{
+					textDialog textdialogW ("QtWarning", tr("You have already added this option","message box message")+" !!<br>", this);
+					textdialogW.exec();
+				}
 			}
 			break;
 		//Execute before list add button
@@ -519,6 +568,21 @@ void modifyDialog::removeListItem(const int type)
 
 }
 
+// Task type combobox changed=====================================================================================================
+// Enable/disable the "keep snapshots" spinbox
+void modifyDialog::TaskTypeChanged(int type)
+{
+	if (type == 2)
+	{
+		uiM.label_snapshotsKeep -> setVisible(FALSE);
+		uiM.spinBox_snapshotsKeep -> setVisible(FALSE);
+	}
+	else
+	{
+		uiM.label_snapshotsKeep -> setVisible(TRUE);
+		uiM.spinBox_snapshotsKeep -> setVisible(TRUE);
+	}
+}
 //===================================================================================================================================================
 //------------------------------------------------------------------FUNCTIONS------------------------------------------------------------------------
 //===================================================================================================================================================
@@ -529,11 +593,19 @@ operation *modifyDialog::fillOperationArray()
 {
 	operation *pTask = new operation;
 	
+	//Before doing any changes, inherit last execution time & error as well as snapshots list from the existing task
+	//if this is not a new task (modify task. NOT new/duplicate/restore task)
+	if (!newTaskThisIs)
+	{
+		pTask -> SetLastExecutionTime (Operation[ArrayPosition] -> GetLastExecutionTime());
+		pTask -> SetLastExecutionErrors (Operation[ArrayPosition] -> GetLastExecutionErrors());
+		pTask -> SetSnapshotsList (Operation[ArrayPosition] -> GetSnapshotsList());
+	}
+	
 	//set operation name --------------------------------------------------------------------------------------------------------
 	pTask -> SetName		( uiM.lineEdit_name -> text() );
 
-	// set Also create restore checkbox & connection ----------------------------------------------------------------------------
-	pTask -> SetAlsoCreateRestore	( uiM.checkBox_alsoCreateRestore -> isChecked() );
+	// set connection ----------------------------------------------------------------------------
 	pTask -> SetConnectRestore	("");
 
 	// set operation type ------------------------------------------------------------------------------
@@ -554,14 +626,24 @@ operation *modifyDialog::fillOperationArray()
 		pTask -> SetTypeDirContents	( FALSE );
 		pTask -> SetTypeDirName		( FALSE );
 		pTask -> SetTypeSync		( TRUE );
+		uiM.spinBox_snapshotsKeep -> setValue (1);	// also set the keep snapshots spinbox to "1" if it is a sync task
 	}
+	
+	// also set the keep snapshots spinbox to "1" if remote destination is used
+	if ( (uiM.groupBox_remote -> isChecked()) && (uiM.radioButton_remoteDestination -> isChecked()) )
+		uiM.spinBox_snapshotsKeep -> setValue (1);
 
 	//set source & destination ------------------------------------------------------------------------------------------------
 	pTask -> SetSource		( uiM.lineEdit_source -> text() );
 	pTask -> SetDestination		( uiM.lineEdit_destination -> text() );
 
+	//set number of snapshots ------------------------------------------------------------------------------------------------
+	pTask -> SetKeepSnapshots	( uiM.spinBox_snapshotsKeep -> value() );
+	
 	//set exclude groupbox & all the info in there -----------------------------------------------------------------------------
 	pTask -> SetExcludeTemp		( uiM.checkBox_excludeTemp -> isChecked() );
+	pTask -> SetExcludeFromFile	( uiM.checkBox_excludeFile -> isChecked() );
+	pTask -> SetExcludeFile		( uiM.lineEdit_excludeFile -> text() );
 	pTask -> SetExcludeCache	( uiM.checkBox_excludeCache -> isChecked() );
 	pTask -> SetExcludeBackup	( uiM.checkBox_excludeBackup -> isChecked() );
 	pTask -> SetExcludeMount	( uiM.checkBox_excludeMount -> isChecked() );
@@ -579,6 +661,9 @@ operation *modifyDialog::fillOperationArray()
 	pTask -> SetExclude ();
 
 	//set include groupbox & all the info in there -----------------------------------------------------------------------------
+	pTask -> SetIncludeFromFile	( uiM.checkBox_includeFile -> isChecked() );
+	pTask -> SetIncludeFile		( uiM.lineEdit_includeFile -> text() );
+	pTask -> SetIncludeModeNormal	( uiM.radioButton_includeNormal -> isChecked() );
 	count = 0;	//read include list one by one
 	while ( count < (uiM.listWidget_include -> count()) )
 	{
@@ -608,6 +693,7 @@ operation *modifyDialog::fillOperationArray()
 	pTask -> SetOptionsDevices	( uiM.checkBox_devices -> isChecked() );
 	pTask -> SetOptionsCVS		( uiM.checkBox_cvs -> isChecked() );
 	pTask -> SetOptionsHardLinks	( uiM.checkBox_hardLinks -> isChecked() );
+	pTask -> SetOptionsFATntfs	( uiM.checkBox_FATntfs -> isChecked() );
 	pTask -> SetOptionsDelete	( uiM.checkBox_deleteAfter -> isChecked() );
 	pTask -> SetOptionsRecurse	( uiM.checkBox_recurse -> isChecked() );
 	count = 0;	//read options list one by one
@@ -644,7 +730,6 @@ operation *modifyDialog::fillOperationArray()
 void modifyDialog::fillModifyWindow(operation *pTask)
 {
 	uiM.lineEdit_name 		-> setText	(pTask -> GetName() );
-	uiM.checkBox_alsoCreateRestore 	-> setChecked	(pTask -> GetAlsoCreateRestore() );
 
 	if (pTask -> GetTypeDirContents())
 		uiM.comboBox_Type -> setCurrentIndex(0);
@@ -655,7 +740,11 @@ void modifyDialog::fillModifyWindow(operation *pTask)
 
 	uiM.lineEdit_source 		-> setText	(pTask -> GetSource() );
 	uiM.lineEdit_destination 	-> setText	(pTask -> GetDestination() );
+	
+	uiM.spinBox_snapshotsKeep	-> setValue	(pTask -> GetKeepSnapshots());
 
+	uiM.checkBox_excludeFile 	-> setChecked	(pTask -> GetExcludeFromFile() );
+	uiM.lineEdit_excludeFile 	-> setText	(pTask -> GetExcludeFile() );
 	uiM.checkBox_excludeTemp 	-> setChecked	(pTask -> GetExcludeTemp() );
 	uiM.checkBox_excludeCache 	-> setChecked	(pTask -> GetExcludeCache() );
 	uiM.checkBox_excludeBackup 	-> setChecked	(pTask -> GetExcludeBackup() );
@@ -670,6 +759,10 @@ void modifyDialog::fillModifyWindow(operation *pTask)
 		count++;
 	}
 
+	uiM.checkBox_includeFile 	-> setChecked	(pTask -> GetIncludeFromFile() );
+	uiM.radioButton_includeNormal 	-> setChecked	(pTask -> GetIncludeModeNormal() );
+	uiM.radioButton_includeOnly 	-> setChecked	(!pTask -> GetIncludeModeNormal() );
+	uiM.lineEdit_includeFile 	-> setText		(pTask -> GetIncludeFile() );
 	count=0;
 	while ( count < (pTask -> GetIncludeListSize()) )
 	{
@@ -698,8 +791,9 @@ void modifyDialog::fillModifyWindow(operation *pTask)
 	uiM.checkBox_symlinks 		-> setChecked	(pTask -> GetOptionsSymlinks() );
 	uiM.checkBox_permissions 	-> setChecked	(pTask -> GetOptionsPermissions() );
 	uiM.checkBox_devices 		-> setChecked	(pTask -> GetOptionsDevices() );
-	uiM.checkBox_cvs 		-> setChecked	(pTask -> GetOptionsCVS() );
+	uiM.checkBox_cvs 			-> setChecked	(pTask -> GetOptionsCVS() );
 	uiM.checkBox_hardLinks 		-> setChecked	(pTask -> GetOptionsHardLinks() );
+	uiM.checkBox_FATntfs 		-> setChecked	(pTask -> GetOptionsFATntfs() );
 	count=0;
 	while ( count < (pTask -> GetOptionsListSize()) )
 	{
@@ -754,6 +848,18 @@ void modifyDialog::modifyTrailing()
 	uiM.lineEdit_destination -> setText(destDir);
 }
 
+// stripInvalidCharacters =============================================================================================================================
+// Replaces all invalid filename characters from a QString with "-"
+QString modifyDialog::stripInvalidCharacters(QString stringToStrip)
+{
+	QString stripedString = stringToStrip;
+	QStringList invalidChars;
+	invalidChars << "/" << "\\" << ":" << "*" << "?" << "\"" << "<" << ">" << "|";
+	
+	foreach (QString charToRemove, invalidChars)
+		stripedString.replace(charToRemove, "", Qt::CaseSensitive);
 
+	return stripedString;
+}
 // end of modifyDialog.cpp ---------------------------------------------------------------------------
 
