@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 27 Nov 2009
+ last modified 		: 11 Jun 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -49,7 +49,7 @@ class modifyDialog : public QDialog
 		void modifyTrailing();			//function to add a remove a trailing "/" at the end of the source or dest dir
 		QStringList StdArguments;		//this variable holds the standard arguments used by rsync
 		int ArrayPosition;			//this holds the item's position in the "operation array"
-		bool validation;			//becomes true if "validation check" button is pressed
+		//bool validation;			//becomes true if "validation check" button is pressed
 		int count;		//simple count variable !!
 
 	private slots:
@@ -61,10 +61,12 @@ class modifyDialog : public QDialog
 		void removeListItem(const int);	//SLOT to remove an item from the excluded list
 		void browse(const int);		//SLOT to browse for a directory or file
 		void getPattern(const int);	//SLOT to launch the pattern editor and insert the pattern to a lineEdit
+		void TaskTypeChanged(int);	// SLOT to act upon task type changes
 
 	private:
 		Ui::modifyDialog uiM;
 		int stdWindowWidth, minWindowHeight, maxWindowHeight;	//standard window dimensions
+		QString stripInvalidCharacters(QString);	//Strips off invalid filename characters from a string
 
 	protected:
 		void closeEvent(QCloseEvent *event);	//when the close button of the dialog pressed
