@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 10 Dec 2009
+ last modified 		: 05 May 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -45,10 +45,17 @@ class operation
 			itsSource = "";
 			itsDestination = "";
 			itsConnectRestore = "";
+			itsLastExecutionErrors = -1;
 			itsExclude = FALSE;
 			itsInclude = FALSE;
+			itsIncludeModeNormal = FALSE;
 			itsByPassWARNING = FALSE;
 			itsCloneWARNING = TRUE;
+			itsKeepSnapshots = 1;
+			itsSnapshotsList.clear();
+			itsOptionsFATntfs = FALSE;
+			itsIncludeFromFile = FALSE;
+			itsExcludeFromFile = FALSE;
 		}
 		~operation() {}								//destructor
 
@@ -67,8 +74,11 @@ class operation
 
 		QDateTime GetLastExecutionTime() const	{return itsLastExecutionTime;}
 		int GetLastExecutionErrors() const	{return itsLastExecutionErrors;}
+		int GetSnapshotsListSize () const 	{return itsSnapshotsList.size();}
+		QStringList GetSnapshotsList () const	{return itsSnapshotsList;}
+		QString GetSnapshotsListItem (int itemPosition) const {return itsSnapshotsList.value(itemPosition);}
+		int GetKeepSnapshots () const 		{return itsKeepSnapshots;}
 
-		bool GetAlsoCreateRestore () const 	{return itsAlsoCreateRestore;}
 		QString GetConnectRestore () const 	{return itsConnectRestore;}
 
 		bool GetTypeDirContents () const 	{return itsTypeDirContents;}
@@ -78,7 +88,9 @@ class operation
 		QString GetSource() const 		{return itsSource;}
 		QString GetDestination() const 		{return itsDestination;}
 
-		bool GetExclude() const 		{return itsExclude;}
+		bool GetExclude() const 			{return itsExclude;}
+		bool GetExcludeFromFile() const		{return itsExcludeFromFile;}
+		QString GetExcludeFile() const		{return itsExcludeFile;}
 		bool GetExcludeTemp() const 		{return itsExcludeTemp;}
 		bool GetExcludeCache () const 		{return itsExcludeCache;}
 		bool GetExcludeBackup () const 		{return itsExcludeBackup;}
@@ -90,6 +102,9 @@ class operation
 		QString GetExcludeListItem (int itemPosition) const {return itsExcludeList.value(itemPosition);}
 
 		bool GetInclude() const 		{return itsInclude;}
+		bool GetIncludeFromFile() const		{return itsIncludeFromFile;}
+		bool GetIncludeModeNormal() const	{return itsIncludeModeNormal;}
+		QString GetIncludeFile() const		{return itsIncludeFile;}
 		int GetIncludeListSize () const 	{return itsIncludeList.size();}
 		QString GetIncludeListItem (int itemPosition) const {return itsIncludeList.value(itemPosition);}
 
@@ -113,6 +128,7 @@ class operation
 		bool GetOptionsDevices () const 	{return itsOptionsDevices;}
 		bool GetOptionsCVS () const 		{return itsOptionsCVS;}
 		bool GetOptionsHardLinks () const 	{return itsOptionsHardLinks;}
+		bool GetOptionsFATntfs() const 		{return itsOptionsFATntfs;}
 		int GetOptionsListSize () const 	{return itsOptionsList.size();}
 		QString GetOptionsListItem (int itemPosition) const {return itsOptionsList.value(itemPosition);}
 
@@ -122,39 +138,57 @@ class operation
 		QString GetExecuteAfterListItem (int itemPosition) const {return itsExecuteAfterList.value(itemPosition);}
 
 		//Functions - set class operation data --------------------------------------------------------------------------------------
-		void SetName(QString name) 				{itsName = name;}	
-		void SetArgs (QStringList arguments) 			{itsArguments = arguments;}
-		void SetIncluded(bool included) 			{itsIncluded = included;}
-		void SetWARNING(bool warning) 				{itsWARNING = warning;}
-		void SetCRITICAL(bool critical) 			{itsCRITICAL = critical;}
-		void SetOK(bool ok) 					{itsOK = ok;}
-		void SetSourcePerms(bool sourceperms) 			{itsSourcePerms = sourceperms;}
-		void SetDestPerms(bool destperms) 			{itsDestPerms = destperms;}
-		void SetPerform(bool perform) 				{itsPerform = perform;}
-		void SetByPassWARNING(bool ByPassWARNING) 		{itsByPassWARNING = ByPassWARNING;}
-		void SetCloneWARNING(bool CloneWARNING) 		{itsCloneWARNING = CloneWARNING;}
+		void SetName(QString name) 							{itsName = name;}
 
+		// Task state & general properties
+		void SetIncluded(bool included) 					{itsIncluded = included;}
+		void SetWARNING(bool warning) 						{itsWARNING = warning;}
+		void SetCRITICAL(bool critical) 					{itsCRITICAL = critical;}
+		void SetOK(bool ok) 								{itsOK = ok;}
+		void SetSourcePerms(bool sourceperms) 				{itsSourcePerms = sourceperms;}
+		void SetDestPerms(bool destperms) 					{itsDestPerms = destperms;}
+		void SetPerform(bool perform) 						{itsPerform = perform;}
+		void SetByPassWARNING(bool ByPassWARNING)			{itsByPassWARNING = ByPassWARNING;}
+		void SetCloneWARNING(bool CloneWARNING) 			{itsCloneWARNING = CloneWARNING;}
+
+		// last execution time & errors
 		void SetLastExecutionTime(QDateTime lastTime)		{itsLastExecutionTime = lastTime;}
 		void SetLastExecutionErrors(int LastExecutionErrors)	{itsLastExecutionErrors = LastExecutionErrors;}
+		
+		// snapshots list
+		void SetSnapshotsList (QStringList snapslist)		{itsSnapshotsList = snapslist;}
+		void AddSnapshotsListItem (QString itemText) 		{itsSnapshotsList.append(itemText);}
+		void ReplaceSnapshotsListItem (int position,QString text)	{itsSnapshotsList.replace(position,text);}
+		void RemoveSnapshotsListItem  (int position)		{itsSnapshotsList.removeAt(position);}
+		void ClearSnapshotsList ()							{itsSnapshotsList.clear();}
+		bool SnapshotsListIsEmpty ()						{return itsSnapshotsList.isEmpty();}
+		void SetKeepSnapshots(int keepsnapshots)			{itsKeepSnapshots = keepsnapshots;}
 
-		void AppendArg (QString argument) 			{itsArguments.append(argument);}
-		void InsertDryRunArg ()					{itsArguments.insert(itsArguments.size()-2,"--dry-run");}
+		// Arguments list
+		void SetArgs (QStringList arguments) 				{itsArguments = arguments;}
+		void AppendArg (QString argument) 					{itsArguments.append(argument);}
+		void InsertDryRunArg ()								{itsArguments.insert(itsArguments.size()-2,"--dry-run");}
 
-		void SetAlsoCreateRestore (bool AlsoCreateRestore)	{  itsAlsoCreateRestore = AlsoCreateRestore;}
+		// connection with other task
 		void SetConnectRestore (QString Connection)		{  itsConnectRestore = Connection;}
 
+		// Task type
 		void SetTypeDirContents (bool TypeDirContents)  	{  itsTypeDirContents = TypeDirContents;}
 		void SetTypeDirName (bool TypeDirName)  		{  itsTypeDirName = TypeDirName;}
 		void SetTypeSync (bool TypeSync)  			{  itsTypeSync = TypeSync;}
 
+		// source & destination
 		void SetSource(QString source) 				{itsSource = source;}
 		void SetDestination(QString destination) 		{itsDestination = destination;}
 
-		void SetExclude()  					{ if ( (itsExcludeTemp)||(itsExcludeCache)||(itsExcludeBackup)||
+		// Exclude ~~~~~~~~~~~
+		// Exclude boolean
+		void SetExclude()  					{ if ( ((itsExcludeFromFile) && !(itsExcludeFile=="")) || (itsExcludeTemp)||(itsExcludeCache)||(itsExcludeBackup)||
 									(itsExcludeMount)||(itsExcludeLostFound)||(itsExcludeSystem)||
 									(itsExcludeTrash)||(itsExcludeList.size()>0) )
 										itsExclude = TRUE;
 									else 	itsExclude = FALSE; }
+		// Exclude templates
 		void SetExcludeTemp(bool ExcludeTemp)  			{  itsExcludeTemp = ExcludeTemp;}
 		void SetExcludeCache (bool ExcludeCache)  		{  itsExcludeCache = ExcludeCache;}
 		void SetExcludeBackup (bool ExcludeBackup)  		{  itsExcludeBackup = ExcludeBackup;}
@@ -162,24 +196,40 @@ class operation
 		void SetExcludeLostFound(bool ExcludeLostFound)  	{  itsExcludeLostFound = ExcludeLostFound;}
 		void SetExcludeSystem(bool ExcludeSystem)  		{  itsExcludeSystem = ExcludeSystem;}
 		void SetExcludeTrash(bool ExcludeTrash)  		{  itsExcludeTrash = ExcludeTrash;}
+		// Exclude from file
+		void SetExcludeFromFile(bool ExcludeFromFile)	{  itsExcludeFromFile = ExcludeFromFile;}
+		void SetExcludeFile(QString ExcludeFile)		{  itsExcludeFile = ExcludeFile;}
+		//Exclude list - user defined
 		void AddExcludeListItem (QString itemText) 		{  itsExcludeList.append(itemText);}
 
-		void SetInclude()	  				{  if (itsIncludeList.size()>0)
+		// Include ~~~~~~~~~~~~~
+		// Include boolean
+		void SetInclude()	  				{  if ( ((itsIncludeFromFile) && !(itsIncludeFile=="")) || 
+											(itsIncludeList.size()>0) )
 										itsInclude = TRUE;
 									else	itsInclude = FALSE;}
+		// Include from file
+		void SetIncludeFromFile(bool IncludeFromFile)		{  itsIncludeFromFile = IncludeFromFile;}
+		// Include mode
+		void SetIncludeModeNormal(bool IncludeModeNormal)	{  itsIncludeModeNormal = IncludeModeNormal;}
+		
+		void SetIncludeFile(QString IncludeFile)		{  itsIncludeFile = IncludeFile;}
+		// Include list
 		void AddIncludeListItem (QString itemText) 		{  itsIncludeList.append(itemText);}
 
-		void SetRemote (bool Remote)  				{  itsRemote = Remote;}
+		// Remote
+		void SetRemote (bool Remote)  					{  itsRemote = Remote;}
 		void SetRemoteModule (bool RemoteModule)  		{  itsRemoteModule = RemoteModule;}
 		void SetRemoteDestination (bool RemoteDestination)  	{  itsRemoteDestination = RemoteDestination;}
 		void SetRemoteSource (bool RemoteSource)  		{  itsRemoteSource = RemoteSource;}
 		void SetRemoteSSH (bool RemoteSSH)  			{  itsRemoteSSH = RemoteSSH;}
 		void SetRemoteHost (QString RemoteHost)  		{  itsRemoteHost = RemoteHost;}
 		void SetRemoteUser (QString RemoteUser)  		{  itsRemoteUser = RemoteUser;}
-		void SetRemotePassword (QString RemotePassword)  	{  itsRemotePassword = RemotePassword;}
+		void SetRemotePassword (QString RemotePassword) {  itsRemotePassword = RemotePassword;}
 		void SetRemoteSSHPassword (QString RemoteSSHPassword)  	{  itsRemoteSSHPassword = RemoteSSHPassword;}
 		void SetRemoteSSHPort (int RemoteSSHPort)  		{  itsRemoteSSHPort = RemoteSSHPort;}
 
+		// Command options - templates
 		void SetOptionsUpdate (bool OptionsUpdate) 		{  itsOptionsUpdate = OptionsUpdate;}
 		void SetOptionsDelete (bool OptionsDelete)  		{  itsOptionsDelete = OptionsDelete;}
 		void SetOptionsRecurse (bool OptionsRecurse)  		{  itsOptionsRecurse = OptionsRecurse;}
@@ -189,8 +239,11 @@ class operation
 		void SetOptionsDevices (bool OptionsDevices)  		{  itsOptionsDevices = OptionsDevices;}
 		void SetOptionsCVS (bool OptionsCVS)  			{  itsOptionsCVS = OptionsCVS;}
 		void SetOptionsHardLinks (bool OptionsHardLinks)  	{  itsOptionsHardLinks = OptionsHardLinks;}
+		void SetOptionsFATntfs (bool OptionsFATntfs)  	{  itsOptionsFATntfs = OptionsFATntfs;}
+		// Command options list - user defined
 		void AddOptionsListItem (QString itemText) 		{  itsOptionsList.append(itemText);}
 
+		// Execute before/after list
 		void AddExecuteBeforeListItem (QString itemText)	{  itsExecuteBeforeList.append(itemText);}
 		void AddExecuteAfterListItem (QString itemText)		{  itsExecuteAfterList.append(itemText);}
 
@@ -208,8 +261,9 @@ class operation
 		bool itsCloneWARNING;
 		QDateTime itsLastExecutionTime;
 		int itsLastExecutionErrors;
+		QStringList itsSnapshotsList;
+		int itsKeepSnapshots;
 
-		bool itsAlsoCreateRestore;
 		QString itsConnectRestore;
 
 		bool itsTypeDirName;
@@ -227,9 +281,14 @@ class operation
 		bool itsExcludeLostFound;
 		bool itsExcludeSystem;
 		bool itsExcludeTrash;
+		bool itsExcludeFromFile;
+		QString itsExcludeFile;
 		QStringList itsExcludeList;
 
 		bool itsInclude;
+		bool itsIncludeFromFile;
+		bool itsIncludeModeNormal;
+		QString itsIncludeFile;
 		QStringList itsIncludeList;
 
 		bool itsRemote;
@@ -252,6 +311,7 @@ class operation
 		bool itsOptionsDevices;
 		bool itsOptionsCVS;
 		bool itsOptionsHardLinks;
+		bool itsOptionsFATntfs;
 		QStringList itsOptionsList;
 
 		QStringList itsExecuteBeforeList;
