@@ -4,7 +4,7 @@
 //===============================================================================================================================
 //===============================================================================================================================
 //     This file is part of "luckyBackup" project
-//     Copyright 2008-2009, Loukas Avgeriou
+//     Copyright 2008-2010, Loukas Avgeriou
 //     luckyBackup is distributed under the terms of the GNU General Public License
 //     luckyBackup is free software: you can redistribute it and/or modify
 //     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 // project version	: Please see "main.cpp" for project version
 
 // developer 		: luckyb 
-// last modified 	: 01 Dec 2009
+// last modified 	: 27 Feb 2009
 //===============================================================================================================================
 //===============================================================================================================================
 
@@ -43,10 +43,14 @@ patternEditor::patternEditor (QString sourceRoot, QWidget *parent) : QDialog (pa
 	uiP.checkBox_pathAbsolute -> setVisible(FALSE);
 	uiP.label_browse -> setText(tr("directory :"));
 	
+	anchorSource="";
 	itsPattern = "no pattern defined yet";
 	SourceRoot = sourceRoot;
 	if (!SourceRoot.endsWith("/"))
+	{
+		anchorSource = sourceRoot.right(sourceRoot.size()-sourceRoot.lastIndexOf("/"));
 		SourceRoot.append("/");
+	}
 	patternLine = "";
 	
 	//connect okay & cancel pushButton SLOTs ----------------
@@ -140,10 +144,11 @@ void patternEditor::browse(const int type)
 			if (newLineEdit != "")	//if something is selected indeed (not cancel pressed)
 			{
 				if (!newLineEdit.startsWith(SourceRoot))
-					QMessageBox::warning(this, appName,
-						tr("Please choose a file within the source")+" :<br><br>" +
-						SourceRoot,
-						QMessageBox::Ok | QMessageBox::Default);
+				{
+					textDialog textdialogW ("QtWarning", tr("Please choose a file within the source")+" :<br><br>" +
+						SourceRoot, this);
+					textdialogW.exec();
+				}
 				else
 					uiP.lineEdit_browse 	-> setText(newLineEdit);
 			}
@@ -159,10 +164,11 @@ void patternEditor::browse(const int type)
 						newLineEdit = "/";
 				
 				if (!newLineEdit.startsWith(SourceRoot))
-					QMessageBox::warning(this, appName,
-						tr("Please choose a directory within the source")+" :<br><br>" +
-						SourceRoot,
-						QMessageBox::Ok | QMessageBox::Default);
+				{
+					textDialog textdialogW ("QtWarning", tr("Please choose a directory within the source")+" :<br><br>" +
+						SourceRoot, this);
+					textdialogW.exec();
+				}
 				else
 					uiP.lineEdit_browse  -> setText(newLineEdit);
 			}
@@ -209,7 +215,7 @@ void patternEditor::fillPattern()
 	{
 		patternLine = uiP.lineEdit_browse -> text();	//first get the string from the path lineEdit
 		if (patternLine.startsWith(SourceRoot))
-			patternLine.replace (SourceRoot, "/");	// replace the starting source in the pattern with /
+			patternLine.replace (SourceRoot, anchorSource + "/");	// replace the starting source in the pattern with /
 	}
 	
 	//go deeper in path ------------------- -------------------------------------------------------------------------------
