@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 25 Nov 2009
+ last modified 		: 08 Mar 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -51,6 +51,7 @@ class schedule
 			itsMinute = 0;
 			itsSkipCritical = TRUE;
 			itsConsoleMode = FALSE;
+			itsReboot = FALSE;
 		}
 		~schedule() {}								//destructor
 
@@ -66,6 +67,7 @@ class schedule
 		int GetMinute () const 			{return itsMinute;}
 		bool GetSkipCritical() const 		{return itsSkipCritical;}
 		bool GetConsoleMode() const 		{return itsConsoleMode;}
+		bool GetReboot() const 			{return itsReboot;}
 
 		//Functions - set class operation data --------------------------------------------------------------------------------------
 		void SetName(QString name) 				{itsName = name;}
@@ -80,7 +82,7 @@ class schedule
 		void SetMinute(int minute) 				{itsMinute = minute;}
 		void SetSkipCritical (bool SkipCritical)  		{itsSkipCritical = SkipCritical;}
 		void SetConsoleMode (bool ConsoleMode)  		{itsConsoleMode = ConsoleMode;}
-
+		void SetReboot (bool Reboot) 	 			{itsReboot = Reboot;}
 
 
 
@@ -95,6 +97,7 @@ class schedule
 		int itsMinute;
 		bool itsSkipCritical;
 		bool itsConsoleMode;
+		bool itsReboot;
 };
 
 #endif
