@@ -4,7 +4,7 @@ Display a dialog. Schedules profiles via cron
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ Display a dialog. Schedules profiles via cron
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 25 Nov 2009
+ last modified 		: 12 Jun 2010
 
 ===============================================================================================================================
 ===============================================================================================================================
@@ -48,6 +48,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 	TotalSchedule=0;		//The number of available profiles schedulesin "schedule list"- starts from 1
 	currentSchedule=0;		//this holds the current row from the "schedule list"- starts from 0
 	noSchedules = TRUE;		//becomes true when no schedules are declared
+	changesMade = FALSE;		//becomes true if changes are made but no cronIt is pressed
 
 	//connections ----------------------------------------------------------------------------------------------------
 	connect(uiS.pushButton_schedule, SIGNAL( pressed() ), this, SLOT(schedulePressed() ) );		//cronIT pushButton
@@ -57,6 +58,8 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 	connect(uiS.pushButton_remove, SIGNAL( pressed() ), this, SLOT(removePressed() ) );		//remove command pushButton
 	connect(uiS.pushButton_modify, SIGNAL( pressed() ), this, SLOT(modifyPressed() ) );		//modify command pushButton
 	
+	connect(uiS.pushButton_viewCrontab, SIGNAL( pressed() ), this, SLOT(viewCrontab() ) );		//view curreent crontab command pushButton
+	
 	connect(uiS.pushButton_modifyOkay, SIGNAL( pressed() ), this, SLOT(okaySchedulePressed() ) );		//modify okay pushButton
 	connect(uiS.pushButton_modifyCancel, SIGNAL( pressed() ), this, SLOT(modifyCancelPressed() ) );		//modify cancel pushButton
 
@@ -115,9 +118,10 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 		
 		if ( (tempAppName != appName) || (tempAppVersion < validScheduleVersion) )//check if the file is a valid luckybackup schedule file
 		{
-			message = tr("The existent schedule file is not a valid luckyBackup v.")
+			message = tr("The existent schedule file is not a valid luckyBackup v.","v is for version")
 				+ countStr.setNum(appVersion) + " "+tr("file")+"<br><br>"+tr("Starting from scratch")+"...<br>" ;
-			QMessageBox::warning(this, appName, message, QMessageBox::Ok | QMessageBox::Default);
+			textDialog textdialogW ("QtWarning", message, this);
+			textdialogW.exec();
 			scheduleFile.remove();
 			return;
 		}
@@ -147,6 +151,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 
 				if (vString == "ScheduleSkipCritical")	tempSchedule	-> SetSkipCritical(v.toBool());
 				if (vString == "ScheduleConsoleMode")	tempSchedule	-> SetConsoleMode(v.toBool());
+				if (vString == "ScheduleAtReboot")	tempSchedule	-> SetReboot(v.toBool());
 
 				in>>v;	vString = v.toString();
 				if (vString!="current schedule end")
@@ -160,7 +165,8 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 									Schedule[currentSchedule] -> GetMonthDay(),
 									Schedule[currentSchedule] -> GetWeekDay(),
 									Schedule[currentSchedule] -> GetHour(),
-									Schedule[currentSchedule] -> GetMinute()));
+									Schedule[currentSchedule] -> GetMinute(),
+									Schedule[currentSchedule] -> GetReboot() ));
 			currentSchedule++;
 		}
 		//TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
@@ -184,7 +190,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 //===================================================================================================================================================
 
 
-// cancel button pressed=====================================================================================================
+// CLOSE button pressed=====================================================================================================
 void scheduleDialog::cancelPressed()
 {
 	close();	//emmit a QcloseEvent
@@ -193,7 +199,19 @@ void scheduleDialog::cancelPressed()
 //window closebutton pressed or QcloseEvent emitted==========================================================================
 void scheduleDialog::closeEvent(QCloseEvent *event)
 {
-	event->accept();
+	if (changesMade)
+	{
+		textDialog textdialogQ ("QtQuestion", tr("You have made changes without clicking the cronIT button") + ".<br>" +
+					tr("Are you sure you want to close the schedule dialog ?"), this);
+		textdialogQ.exec();
+
+		if (textdialogQ.getGoOn() > 0)		//if user answers yes
+			event->accept();
+		else
+			event->ignore();
+	}
+	else
+		event->accept();
 }
 
 
@@ -214,7 +232,10 @@ void scheduleDialog::schedulePressed()
 		uiS.listWidget_schedule -> takeItem (0);
 
 	if (!scheduleFile.open(QIODevice::WriteOnly))	//create a new schedule file
-		QMessageBox::information(this, appName, tr("Unable to create schedule file")+" !!<br><br>"+ scheduleFile.errorString());
+	{
+		textDialog textdialogI ("QtInformation", tr("Unable to create schedule file")+" !!<br><br>"+ scheduleFile.errorString(), this);
+		textdialogI.exec();
+	}
 	else 		//write some stuff to schedule file
 	{
  		QDataStream out(&scheduleFile);
@@ -241,6 +262,7 @@ void scheduleDialog::schedulePressed()
 
 			v = "ScheduleSkipCritical";out << v;	v = Schedule[currentSchedule] -> GetSkipCritical();		out << v;
 			v = "ScheduleConsoleMode";out << v;	v = Schedule[currentSchedule] -> GetConsoleMode();		out << v;
+			v = "ScheduleAtReboot";	out << v;	v = Schedule[currentSchedule] -> GetReboot();			out << v;
 
 			v = "current schedule end";	out << v;
 			
@@ -253,8 +275,13 @@ void scheduleDialog::schedulePressed()
 	
 	createCron();		//create a cronfile & update user's crontab
 	crontabUpdated = TRUE;
+	changesMade = FALSE;
+
+	textDialog textdialogI ("QtInformation",  "<font color=blue><b>" + currentUser + "</b></font><br><br>" +
+				tr("Your crontab is updated successfully"), this);
+	textdialogI.exec();
 	
-	close();		//emmit a QcloseEvent
+	//close();		//emmit a QcloseEvent
 }
 
 // add button pressed=====================================================================================================
@@ -286,6 +313,7 @@ void scheduleDialog::addPressed()
 	uiS.pushButton_remove -> setEnabled(FALSE);
 	uiS.pushButton_cancel -> setEnabled(FALSE);
 	uiS.pushButton_schedule -> setEnabled(FALSE);
+	uiS.pushButton_viewCrontab -> setEnabled(FALSE);
 	clearScheduleDetails();
 }
 
@@ -305,6 +333,7 @@ void scheduleDialog::modifyPressed()
 	uiS.pushButton_remove -> setEnabled(FALSE);
 	uiS.pushButton_cancel -> setEnabled(FALSE);
 	uiS.pushButton_schedule -> setEnabled(FALSE);
+	uiS.pushButton_viewCrontab -> setEnabled(FALSE);
 }
 
 
@@ -326,6 +355,25 @@ void scheduleDialog::removePressed()
 		noSchedules = TRUE;
 		uiS.listWidget_schedule -> addItem(tr("No schedules are declared !!"));
 	}
+	changesMade = TRUE;
+}
+
+// current button pressed==============================================================================================
+// Displays the current crontab
+void scheduleDialog::viewCrontab()
+{
+	// copy user's crontab to QString CronTab
+	CronTab = "";
+	cronProcess -> start ("crontab",QStringList() << "-l");	// execute crontab -l command & capture output to QString CronTab
+	cronProcess -> waitForStarted();
+	cronProcess -> waitForFinished();
+
+	if (CronTab == "")
+		CronTab = currentUser + " - " + tr("no crontab entries exist");
+	else
+		CronTab.prepend("User: " + currentUser + " - " + tr("crontab content") + "\n\n");
+	textDialog textdialog ("ViewCurrentCrontab", CronTab, this);
+	textdialog.exec();
 }
 
 // modify cancel button pressed=================================================================================================
@@ -339,6 +387,7 @@ void scheduleDialog::modifyCancelPressed()
 	uiS.pushButton_remove -> setEnabled(TRUE);
 	uiS.pushButton_cancel -> setEnabled(TRUE);
 	uiS.pushButton_schedule -> setEnabled(TRUE);
+	uiS.pushButton_viewCrontab -> setEnabled(TRUE);
 
 	TotalSchedule = uiS.listWidget_schedule -> count();	//Get the schedule list size
 	if (TotalSchedule == 0)
@@ -361,6 +410,7 @@ void scheduleDialog::clearScheduleDetails()
 	uiS.spinBox_minute -> setValue(0);
 	uiS.checkBox_skipCritical -> setCheckState(Qt::Checked);
 	uiS.checkBox_consoleMode -> setCheckState(Qt::Unchecked);
+	uiS.checkBox_reboot -> setCheckState(Qt::Unchecked);
 }
 
 // fillDetails=====================================================================================================
@@ -388,6 +438,10 @@ void scheduleDialog::fillDetails()
 		uiS.checkBox_consoleMode -> setCheckState(Qt::Checked);
 	else
 		uiS.checkBox_consoleMode -> setCheckState(Qt::Unchecked);
+	if (Schedule[currentSchedule] -> GetReboot())
+		uiS.checkBox_reboot -> setCheckState(Qt::Checked);
+	else
+		uiS.checkBox_reboot -> setCheckState(Qt::Unchecked);
 }
 
 // okaySchedulePressed=====================================================================================================
@@ -419,7 +473,7 @@ void scheduleDialog::okaySchedulePressed()
 			in >> v;	tempAppVersion = v.toDouble();
 		if ( (tempAppName != appName) || (tempAppVersion < validProfileVersion) )//check if the file is a valid luckybackup profile
 		{
-			message = tr("The profile you are trying to open is not a valid luckyBackup v.")+" "
+			message = tr("The profile you are trying to open is not a valid luckyBackup v.","v is for version")+" "
 				+ countStr.setNum(appVersion) + " "+tr("profile")+"<br><br>";
 			QMessageBox::warning(this, appName, message, QMessageBox::Ok | QMessageBox::Default);
 			return;
@@ -431,6 +485,7 @@ void scheduleDialog::okaySchedulePressed()
 	tempOp -> SetProfileName (uiS.comboBox_profile -> currentText());
 	tempOp -> SetProfilePath (profileDir + uiS.comboBox_profile -> currentText() + ".profile");
 
+	tempOp -> SetReboot (uiS.checkBox_reboot -> isChecked());
 	tempOp -> SetMonth (uiS.comboBox_month -> currentIndex());
 	tempOp -> SetMonthDay (uiS.comboBox_dayOfMonth -> currentIndex());
 	tempOp -> SetWeekDay (uiS.comboBox_DayOfWeek -> currentIndex());
@@ -443,12 +498,13 @@ void scheduleDialog::okaySchedulePressed()
 			tempOp -> GetMonthDay(),
 			tempOp -> GetWeekDay(),
 			tempOp -> GetHour(),
-			tempOp -> GetMinute()));
+			tempOp -> GetMinute(),
+			tempOp -> GetReboot()));
 	Schedule[currentSchedule] = tempOp;
 
 	if (currentSchedule == TotalSchedule)
 	{
-		uiS.listWidget_schedule -> addItem( Schedule[currentSchedule] -> GetName() );	//add item at schedule listt
+		uiS.listWidget_schedule -> addItem( Schedule[currentSchedule] -> GetName() );	//add item at schedule list
 		uiS.listWidget_schedule -> setCurrentRow(currentSchedule);
 	}
 	else	//take out the selected item from the list & insert a new one at the same position with the new name
@@ -457,95 +513,104 @@ void scheduleDialog::okaySchedulePressed()
 	TotalSchedule = uiS.listWidget_schedule -> count();		//set the TotalSchedule to what it is now
 
 	modifyCancelPressed();
+	changesMade = TRUE;
 }
 
 // scheduleText=====================================================================================================
 // returns the text displayed at the schedule list (eg execute profile default at .... every...)
-QString scheduleDialog::scheduleText(QString name,int month,int monthday, int weekday, int hour, int minute)
+QString scheduleDialog::scheduleText(QString name,int month,int monthday, int weekday, int hour, int minute, bool reboot)
 {
-			QString tempProfileName = tr("Execute profile")+" '"+ name + "', "+tr("at")+" ";
-			if (hour < 10)
-				tempProfileName.append("0"+countStr.setNum(hour) + ":");
-			else
-				tempProfileName.append(countStr.setNum(hour) + ":");
-			if (minute < 10) 
-				tempProfileName.append("0"+countStr.setNum(minute));
-			else
-				tempProfileName.append(countStr.setNum(minute));
-			tempProfileName.append(", "+tr("every")+" ");
+	QString tempProfileName = tr("Execute profile")+" '"+ name + "', ";
+	if (reboot)
+	{
+		tempProfileName.append(tr("once, at system startup","full phrase: Execute profile xxxxx, once at system startup"));
+		return tempProfileName;
+	}
+	
+	
+	tempProfileName.append(tr("at")+" ");
+	if (hour < 10)
+		tempProfileName.append("0"+countStr.setNum(hour) + ":");
+	else
+		tempProfileName.append(countStr.setNum(hour) + ":");
+	if (minute < 10) 
+		tempProfileName.append("0"+countStr.setNum(minute));
+	else
+		tempProfileName.append(countStr.setNum(minute));
+	tempProfileName.append(", "+tr("every")+" ");
 
-			if ((weekday==0) && (monthday== 0))
-				tempProfileName.append(tr("day"));
-			if (weekday==1)
-				tempProfileName.append(tr("Sunday"));
-			if (weekday==2)
-				tempProfileName.append(tr("Monday"));
-			if (weekday==3)
-				tempProfileName.append(tr("Tuesday"));
-			if (weekday==4)
-				tempProfileName.append(tr("Wednesday"));
-			if (weekday==5)
-				tempProfileName.append(tr("Thursday"));
-			if (weekday==6)
-				tempProfileName.append(tr("Friday"));
-			if (weekday==7)
-				tempProfileName.append(tr("Saturday"));
+	if ((weekday==0) && (monthday== 0))
+		tempProfileName.append(tr("day"));
+	if (weekday==1)
+		tempProfileName.append(tr("Sunday"));
+	if (weekday==2)
+		tempProfileName.append(tr("Monday"));
+	if (weekday==3)
+		tempProfileName.append(tr("Tuesday"));
+	if (weekday==4)
+		tempProfileName.append(tr("Wednesday"));
+	if (weekday==5)
+		tempProfileName.append(tr("Thursday"));
+	if (weekday==6)
+		tempProfileName.append(tr("Friday"));
+	if (weekday==7)
+		tempProfileName.append(tr("Saturday"));
 
-			if (monthday != 0) 
-			{
-				if (weekday!=0)
-					tempProfileName.append(" "+tr("& on the")+" ");
+	if (monthday != 0) 
+	{
+		if (weekday!=0)
+			tempProfileName.append(" "+tr("& on the")+" ");
 
-				tempProfileName.append(countStr.setNum(monthday));
-				
-				if (monthday == 1) tempProfileName.append(tr("st","as in 1st day"));
-				if (monthday == 2) tempProfileName.append(tr("nd","as in 2nd day"));
-				if (monthday == 3) tempProfileName.append(tr("rd","as in 3rd day"));
-				if ((monthday > 3) && (monthday < 8)) tempProfileName.append(tr("th","as in 4th, 5th, 6th or 7th day"));
-				if (monthday == 8) tempProfileName.append(tr("th","as in 8th day"));
-				if (monthday == 9) tempProfileName.append(tr("th","as in 9th day"));
-				if (monthday == 10) tempProfileName.append(tr("th","as in 10th day"));
-				if (monthday == 11) tempProfileName.append(tr("th","as in 11th day"));
-				if ((monthday > 11) && (monthday < 20)) tempProfileName.append(tr("th","as in 12th....19th day"));
-				if (monthday == 20) tempProfileName.append(tr("th","as in 20th day"));
-				if (monthday == 21) tempProfileName.append(tr("st","as in 21st day"));
-				if (monthday == 22) tempProfileName.append(tr("nd","as in 22nd day"));
-				if (monthday == 23) tempProfileName.append(tr("rd","as in 23rd day"));
-				if ((monthday > 23) && (monthday < 31)) tempProfileName.append(tr("th","as in 24th...30th day"));
-				if (monthday == 31) tempProfileName.append(tr("st","as in 31st day"));
-				tempProfileName.append(" "+tr("day"));
-			}
-			if (month == 0)
-			{
-				tempProfileName.append(" "+tr("of any month"));
-				return tempProfileName;
-			}
-			if (month == 1)
-				tempProfileName.append(" "+tr("of")+" "+tr("January","full phrase: 'of January'"));
-			if (month == 2)
-				tempProfileName.append(" "+tr("of")+" "+tr("February","full phrase: 'of February'"));
-			if (month == 3)
-				tempProfileName.append(" "+tr("of")+" "+tr("March","full phrase: 'of March'"));
-			if (month == 4)
-				tempProfileName.append(" "+tr("of")+" "+tr("April","full phrase: 'of April'"));
-			if (month == 5)
-				tempProfileName.append(" "+tr("of")+" "+tr("May","full phrase: 'of May'"));
-			if (month == 6)
-				tempProfileName.append(" "+tr("of")+" "+tr("June","full phrase: 'of June'"));
-			if (month == 7)
-				tempProfileName.append(" "+tr("of")+" "+tr("July","full phrase: 'of July'"));
-			if (month == 8)
-				tempProfileName.append(" "+tr("of")+" "+tr("August","full phrase: 'of August'"));
-			if (month == 9)
-				tempProfileName.append(" "+tr("of")+" "+tr("September","full phrase: 'of September'"));
-			if (month == 10)
-				tempProfileName.append(" "+tr("of")+" "+tr("October","full phrase: 'of October'"));
-			if (month == 11)
-				tempProfileName.append(" "+tr("of")+" "+tr("November","full phrase: 'of November'"));
-			if (month == 12)
-				tempProfileName.append(" "+tr("of")+" "+tr("December","full phrase: 'of December'"));
+		tempProfileName.append(countStr.setNum(monthday));
+		
+		if (monthday == 1) tempProfileName.append(tr("st","as in 1st day"));
+		if (monthday == 2) tempProfileName.append(tr("nd","as in 2nd day"));
+		if (monthday == 3) tempProfileName.append(tr("rd","as in 3rd day"));
+		if ((monthday > 3) && (monthday < 8)) tempProfileName.append(tr("th","as in 4th, 5th, 6th or 7th day"));
+		if (monthday == 8) tempProfileName.append(tr("th","as in 8th day"));
+		if (monthday == 9) tempProfileName.append(tr("th","as in 9th day"));
+		if (monthday == 10) tempProfileName.append(tr("th","as in 10th day"));
+		if (monthday == 11) tempProfileName.append(tr("th","as in 11th day"));
+		if ((monthday > 11) && (monthday < 20)) tempProfileName.append(tr("th","as in 12th....19th day"));
+		if (monthday == 20) tempProfileName.append(tr("th","as in 20th day"));
+		if (monthday == 21) tempProfileName.append(tr("st","as in 21st day"));
+		if (monthday == 22) tempProfileName.append(tr("nd","as in 22nd day"));
+		if (monthday == 23) tempProfileName.append(tr("rd","as in 23rd day"));
+		if ((monthday > 23) && (monthday < 31)) tempProfileName.append(tr("th","as in 24th...30th day"));
+		if (monthday == 31) tempProfileName.append(tr("st","as in 31st day"));
+		tempProfileName.append(" "+tr("day"));
+	}
+	if (month == 0)
+	{
+		tempProfileName.append(" "+tr("of any month"));
+		return tempProfileName;
+	}
+	if (month == 1)
+		tempProfileName.append(" "+tr("of")+" "+tr("January","full phrase: 'of January'"));
+	if (month == 2)
+		tempProfileName.append(" "+tr("of")+" "+tr("February","full phrase: 'of February'"));
+	if (month == 3)
+		tempProfileName.append(" "+tr("of")+" "+tr("March","full phrase: 'of March'"));
+	if (month == 4)
+		tempProfileName.append(" "+tr("of")+" "+tr("April","full phrase: 'of April'"));
+	if (month == 5)
+		tempProfileName.append(" "+tr("of")+" "+tr("May","full phrase: 'of May'"));
+	if (month == 6)
+		tempProfileName.append(" "+tr("of")+" "+tr("June","full phrase: 'of June'"));
+	if (month == 7)
+		tempProfileName.append(" "+tr("of")+" "+tr("July","full phrase: 'of July'"));
+	if (month == 8)
+		tempProfileName.append(" "+tr("of")+" "+tr("August","full phrase: 'of August'"));
+	if (month == 9)
+		tempProfileName.append(" "+tr("of")+" "+tr("September","full phrase: 'of September'"));
+	if (month == 10)
+		tempProfileName.append(" "+tr("of")+" "+tr("October","full phrase: 'of October'"));
+	if (month == 11)
+		tempProfileName.append(" "+tr("of")+" "+tr("November","full phrase: 'of November'"));
+	if (month == 12)
+		tempProfileName.append(" "+tr("of")+" "+tr("December","full phrase: 'of December'"));
 
-			return tempProfileName;
+	return tempProfileName;
 }
 
 // createCron=====================================================================================================
@@ -554,6 +619,7 @@ void scheduleDialog::createCron()
 {
 	QString ScheduleLine = "";
 	QString ProfilePath="";
+	QString ProfileName="";
 	QString luckyEntryStart = "\n# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ luckybackup entries ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
 	QString luckyEntryEnd = "# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ end of luckybackup entries ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
 
@@ -580,21 +646,26 @@ void scheduleDialog::createCron()
 		currentSchedule = 0;
 		while (currentSchedule < TotalSchedule)
 		{
-			ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMinute()) + " ");	//minute
-			ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetHour()) + " ");	//hour
-			if (Schedule[currentSchedule] -> GetMonthDay() == 0)					//Day of month
-				ScheduleLine.append("* ");
-			else
-				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMonthDay()) + " ");
-			if (Schedule[currentSchedule] -> GetMonth() == 0)					//Month
-				ScheduleLine.append("* ");
-			else
-				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMonth()) + " ");
-			if (Schedule[currentSchedule] -> GetWeekDay() == 0)					//Day of week
-				ScheduleLine.append("*	");
-			else
-				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetWeekDay() -1 ) + "	");
-
+			if (Schedule[currentSchedule] -> GetReboot())			//append @reboot if checkbox selected
+				ScheduleLine.append("@reboot	");
+			else									// else append time-day eth
+			{
+				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMinute()) + " ");	//minute
+				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetHour()) + " ");	//hour
+				if (Schedule[currentSchedule] -> GetMonthDay() == 0)					//Day of month
+					ScheduleLine.append("* ");
+				else
+					ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMonthDay()) + " ");
+				if (Schedule[currentSchedule] -> GetMonth() == 0)					//Month
+					ScheduleLine.append("* ");
+				else
+					ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMonth()) + " ");
+				if (Schedule[currentSchedule] -> GetWeekDay() == 0)					//Day of week
+					ScheduleLine.append("*	");
+				else
+					ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetWeekDay() -1 ) + "	");
+			}
+			
 			if (Schedule[currentSchedule] -> GetConsoleMode())			//append -c --no-questions for CL or --silent for gui
 				ScheduleLine.append("/usr/bin/luckybackup -c --no-questions ");
 			else
@@ -606,7 +677,12 @@ void scheduleDialog::createCron()
 			ProfilePath = Schedule[currentSchedule] -> GetProfilePath();
 			ProfilePath.replace(" ", "\\ ");
 			ScheduleLine.append(ProfilePath);	//append profile full path
-			ScheduleLine.append(" >> " + cronlogfilename + " 2>&1"+ "\n");		//append logfile output with >> instead of single >
+			
+			// append cron logfile part
+			ProfileName = Schedule[currentSchedule] -> GetProfileName();
+			ProfileName.replace(" ", "\\ ");
+			ScheduleLine.append(" > " + logDir + ProfileName + "-" + cronlogString +
+					" 2>&1"+ "\n");		//append logfile output with >> instead of single >
 
 			out << ScheduleLine;
 
@@ -639,7 +715,9 @@ void scheduleDialog::createCron()
 //appends the user's crontab to a QString
 void scheduleDialog::appendCrontabOutput()
 {
-	CronTab = QString(cronProcess -> readAllStandardOutput());
+	QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+	CronTab = codec->toUnicode(cronProcess -> readAllStandardOutput());
+	//CronTab = QString(cronProcess -> readAllStandardOutput());
 }
 
 // end of scheduleDialog.cpp ---------------------------------------------------------------------------
