@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2009, Loukas Avgeriou
+     Copyright 2008-2010, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  project version	: Please see "main.cpp" for project version
 
  developer 		: luckyb 
- last modified 		: 05 Nov 2009
+ last modified 		: 08 Mar 2010
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -51,7 +51,7 @@ class scheduleDialog : public QDialog
 		QString CronTab;		//QString to hold the user's crontab
 		int count;			//simple count variable !!
 		void clearScheduleDetails();	//function: when clear (schedule details) pushbutton pressed
-		QString scheduleText(QString,int,int,int,int,int);		//returns the text displayed at the schedule list (eg execute profile default at .... every...)
+		QString scheduleText(QString,int,int,int,int,int,bool);		//returns the text displayed at the schedule list (eg execute profile default at .... every...)
 
 
 	private slots:
@@ -63,6 +63,7 @@ class scheduleDialog : public QDialog
 		void removePressed();		//SLOT to remove an item from the list
 		void okaySchedulePressed();	//function to add ot modify a profile schedule
 		void modifyCancelPressed();	//SLOT to initialize widget views
+		void viewCrontab();		//SLOT to display the currenr crontab
 
 		void fillDetails();		//SLOT to fill fields of schedule details
 		void appendCrontabOutput();	//SLOT to read user's crontab to a QString
@@ -71,6 +72,7 @@ class scheduleDialog : public QDialog
 		Ui::scheduleDialog uiS;
 		int currentProfileIndex;	//holds the current profile index inside the combobox
 		bool noSchedules;		//becomes true when no schedules are declared
+		bool changesMade;		//becomes true if changes are made but no cronIt is pressed
 	
 
 	protected:
