@@ -4,7 +4,7 @@
 //===============================================================================================================================
 //===============================================================================================================================
 //     This file is part of "luckyBackup" project
-//     Copyright 2008-2009, Loukas Avgeriou
+//     Copyright 2008-2010, Loukas Avgeriou
 //     luckyBackup is distributed under the terms of the GNU General Public License
 //     luckyBackup is free software: you can redistribute it and/or modify
 //     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 // project version	: Please see "main.cpp" for project version
 
 // developer 		: luckyb 
-// last modified 	: 12 Dec 2009
+// last modified 	: 04 Jun 2010
 //===============================================================================================================================
 //===============================================================================================================================
 
@@ -43,6 +43,7 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 
 	GoOn = 0;
 	Type = type;
+	TextPassed = ReplaceInput;
 	if (type == "NewProfile")
 	{
 		uiT.label_message 	-> setText(tr("Enter the name of the new profile :"));
@@ -82,6 +83,61 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 		uiT.label_message 	-> setText(tr("You have selected to \"Backup the contents of the source directory\"<br>together with the \"delete files on the destination\" option") +"<br><br>" + tr("BEWARE, if your intention is NOT to clone source to destination !!") +"<br><br>" + 
 				tr("Are you sure you wish to proceed ??") + "<br><br>");
 	}
+	if (type == "ValidateDialog")
+	{
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_warning -> setVisible(TRUE);
+		uiT.label_warning -> setPixmap(QPixmap(":/luckyPrefix/validate.png"));
+		uiT.pushButton_cancel -> setText(tr("Copy command to clipboard"));
+		uiT.pushButton_cancel -> setIcon(QIcon(":/luckyPrefix/copy.png"));
+		uiT.label_message 	-> setText(ReplaceInput);
+	}
+	if (type == "ViewCurrentCrontab")
+	{
+		this -> resize(640, 480);
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.pushButton_cancel -> setVisible(FALSE);
+		uiT.label_message 	-> setText(ReplaceInput);
+	}
+	
+	// The next are used instead of standard Qt dialogs for translation reasons
+	if (type == "QtInformation")
+	{
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/validate.png"));
+		uiT.label_message 	-> setText(ReplaceInput);
+		
+		uiT.pushButton_cancel 	-> setVisible(FALSE);
+	}
+	if (type == "QtWarning")
+	{
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/warning.png"));
+		uiT.label_message 	-> setText(ReplaceInput);
+		
+		uiT.pushButton_cancel 	-> setVisible(FALSE);
+	}
+	if (type == "QtCritical")
+	{
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/cancel.png"));
+		uiT.label_message 	-> setText(ReplaceInput);
+		
+		uiT.pushButton_cancel 	-> setVisible(FALSE);
+	}
+	if (type == "QtQuestion")
+	{
+		uiT.lineEdit_userInput 	-> setVisible(FALSE);
+		uiT.label_warning 	-> setVisible(TRUE);
+		uiT.label_warning 	-> setPixmap(QPixmap(":/luckyPrefix/about.png"));
+		uiT.label_message 	-> setText(ReplaceInput);
+		
+		uiT.pushButton_cancel 	-> setText(tr("No"));
+		uiT.pushButton_ok 	-> setText(tr("Yes"));
+	}
 }
 // SLOTS-------------------------------------------------------------------------------------
 // --------------------------------okay pressed------------------------------------------------
@@ -121,7 +177,40 @@ void textDialog::okay()
 void textDialog::cancel()
 {
 	//GoOn == 0
-	close();
+	if (Type == "ValidateDialog")
+	{
+		QString source, dest, Command_Clipboard;
+	
+		//copy command to clipboard		
+		TextPassed = TextPassed.right(TextPassed.size()-TextPassed.indexOf("<font color=red>")); 	//remove all irrelevant text
+		source = TextPassed.right(TextPassed.size()-TextPassed.indexOf("<font color=magenta>"));	//copy source & dest inside QString source
+		TextPassed.remove(source);																	//remove source & dest from whole command
+		dest = source.right(source.size()-source.lastIndexOf("<font color=magenta>"));				//copy dest inside QString dest
+		source.remove(dest);																		//remove dest from source
+
+		source.remove("<font color=magenta>",Qt::CaseSensitive);
+		source.remove("</font>",Qt::CaseSensitive);
+		source.remove("<br>",Qt::CaseSensitive);
+		if (source.endsWith(" "))
+			source.chop(1);
+		source.replace(" ","\\ ");																	//replace whitespaces with " \"
+
+		dest.remove("<font color=magenta>",Qt::CaseSensitive);
+		dest.remove("</font>",Qt::CaseSensitive);
+		dest.remove("<br>",Qt::CaseSensitive);
+		dest.replace(" ","\\ ");	
+		
+		Command_Clipboard = TextPassed + source + " " + dest;
+		Command_Clipboard.remove("<font color=red>",Qt::CaseSensitive);
+		Command_Clipboard.remove("<font color=blue>",Qt::CaseSensitive);
+		Command_Clipboard.remove("</font>",Qt::CaseSensitive);
+		Command_Clipboard.remove("<br>",Qt::CaseSensitive);
+		
+		QClipboard *clipboard = QApplication::clipboard();
+		clipboard->setText(Command_Clipboard);
+	}
+	else
+		close();
 }
 
 void textDialog::closeEvent(QCloseEvent *event)
